SystemOrganization addCategory: #'Pier-Tests-Core'!
SystemOrganization addCategory: #'Pier-Tests-Kernel'!
SystemOrganization addCategory: #'Pier-Tests-Persistence'!
SystemOrganization addCategory: #'Pier-Tests-Structure'!
SystemOrganization addCategory: #'Pier-Tests-Command'!
SystemOrganization addCategory: #'Pier-Tests-Document'!
SystemOrganization addCategory: #'Pier-Tests-Utilities'!
SystemOrganization addCategory: #'Pier-Tests-Mocks'!

TestCase subclass: #PRDocumentParserTest
	instanceVariableNames: 'parser'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Pier-Tests-Document'!

!PRDocumentParserTest methodsFor: 'running' stamp: 'lr 4/5/2007 13:53'!
setUp
	parser := PRDocumentParser new! !

!PRDocumentParserTest methodsFor: 'testing-escaping' stamp: 'lr 4/5/2007 14:04'!
testEscape1
	self assert: (parser class escape: '' using: 'a') = ''.
	self assert: (parser class escape: 'a' using: 'a') = '\a'.
	self assert: (parser class escape: 'ab' using: 'a') = '\ab'.
	self assert: (parser class escape: 'ba' using: 'a') = 'b\a'.
	self assert: (parser class escape: 'bab' using: 'a') = 'b\ab'! !

!PRDocumentParserTest methodsFor: 'testing-escaping' stamp: 'lr 4/5/2007 14:05'!
testEscape2
	self assert: (parser class escape: 'aa' using: 'a') = '\a\a'.
	self assert: (parser class escape: 'aab' using: 'a') = '\a\ab'.
	self assert: (parser class escape: 'baa' using: 'a') = 'b\a\a'.
	self assert: (parser class escape: 'baab' using: 'a') = 'b\a\ab'! !

!PRDocumentParserTest methodsFor: 'testing-escaping' stamp: 'lr 4/5/2007 15:54'!
testEscape3
	self assert: (parser class escape: 'a' using: 'aa') = 'a'.
	self assert: (parser class escape: 'aa' using: 'aa') = '\aa'.
	self assert: (parser class escape: 'aaa' using: 'aa') = '\aaa'.
	self assert: (parser class escape: 'aaaa' using: 'aa') = '\aa\aa'! !

!PRDocumentParserTest methodsFor: 'testing' stamp: 'lr 4/5/2007 13:57'!
testFindFirstAtIn1
	self assert: (parser findFirst: 'ab' at: 1 in: '') = 0.
	self assert: (parser findFirst: 'ab' at: 1 in: 'ab') = 1.
	self assert: (parser findFirst: 'ab' at: 1 in: 'cab') = 2.
	self assert: (parser findFirst: 'ab' at: 1 in: '\ab') = 0.
	self assert: (parser findFirst: 'ab' at: 1 in: 'c\ab') = 0.
	self assert: (parser findFirst: 'ab' at: 1 in: '\abab') = 4.
	self assert: (parser findFirst: 'ab' at: 1 in: 'c\abab') = 5! !

!PRDocumentParserTest methodsFor: 'testing' stamp: 'lr 4/5/2007 13:57'!
testFindFirstAtIn2
	self assert: (parser findFirst: 'ab' at: 2 in: 'ab') = 0.
	self assert: (parser findFirst: 'ab' at: 2 in: 'cab') = 2.
	self assert: (parser findFirst: 'ab' at: 5 in: '\abab') = 0.
	self assert: (parser findFirst: 'ab' at: 5 in: 'c\abab') = 5! !

!PRDocumentParserTest methodsFor: 'testing' stamp: 'lr 4/6/2007 22:02'!
testNextCrLf1
	parser initializeOn: ('a' , String cr , 'b') readStream.
	self assert: parser nextLine = 'a'.
	self assert: parser nextLine = 'b'.
	self assert: parser nextLine isNil.

	parser initializeOn: ('a' , String lf , 'b') readStream.
	self assert: parser nextLine = 'a'.
	self assert: parser nextLine = 'b'.
	self assert: parser nextLine isNil.

	parser initializeOn: ('a' , String cr , String lf , 'b') readStream.
	self assert: parser nextLine = 'a'.
	self assert: parser nextLine = 'b'.
	self assert: parser nextLine isNil! !

!PRDocumentParserTest methodsFor: 'testing' stamp: 'lr 4/6/2007 22:03'!
testNextCrLf2
	parser initializeOn: (String lf , 'a') readStream.
	self assert: parser nextLine = ''.
	self assert: parser nextLine = 'a'.
	self assert: parser nextLine isNil.

	parser initializeOn: (String cr , 'a') readStream.
	self assert: parser nextLine = ''.
	self assert: parser nextLine = 'a'.
	self assert: parser nextLine isNil.

	parser initializeOn: (String cr , String lf , 'a') readStream.
	self assert: parser nextLine = ''.
	self assert: parser nextLine = 'a'.
	self assert: parser nextLine isNil! !

!PRDocumentParserTest methodsFor: 'testing' stamp: 'lr 4/6/2007 22:03'!
testNextCrLf3
	parser initializeOn: ('a' , String lf) readStream.
	self assert: parser nextLine = 'a'.
	self assert: parser nextLine isNil.

	parser initializeOn: ('a' , String cr) readStream.
	self assert: parser nextLine = 'a'.
	self assert: parser nextLine isNil.

	parser initializeOn: ('a' , String cr , String lf) readStream.
	self assert: parser nextLine = 'a'.
	self assert: parser nextLine isNil! !

!PRDocumentParserTest methodsFor: 'testing' stamp: 'lr 5/28/2007 16:31'!
testNextCrLf4
	parser initializeOn: (String lf , String lf) readStream.
	self assert: parser nextLine = ''.
	self assert: parser nextLine = ''.
	self assert: parser nextLine isNil.

	parser initializeOn: (String cr , String cr) readStream.
	self assert: parser nextLine = ''.
	self assert: parser nextLine = ''.
	self assert: parser nextLine isNil.

	parser initializeOn: (String cr , String lf) readStream.
	self assert: parser nextLine = ''.
	self assert: parser nextLine isNil.

	parser initializeOn: (String lf , String cr) readStream.
	self assert: parser nextLine = ''.
	self assert: parser nextLine = ''.
	self assert: parser nextLine isNil! !

!PRDocumentParserTest methodsFor: 'testing-escaping' stamp: 'lr 4/5/2007 14:02'!
testUnescape1
	self assert: (parser class unescape: '\a') = 'a'.
	self assert: (parser class unescape: '\ab') = 'ab'.
	self assert: (parser class unescape: 'b\a') = 'ba'.
	self assert: (parser class unescape: 'b\ab') = 'bab'! !

!PRDocumentParserTest methodsFor: 'testing-escaping' stamp: 'lr 4/5/2007 14:02'!
testUnescape2
	self assert: (parser class unescape: '\a\a') = 'aa'.
	self assert: (parser class unescape: '\a\ab') = 'aab'.
	self assert: (parser class unescape: 'b\a\a') = 'baa'.
	self assert: (parser class unescape: 'b\a\ab') = 'baab'! !

!PRDocumentParserTest methodsFor: 'testing-escaping' stamp: 'lr 4/5/2007 14:03'!
testUnescape3
	self assert: (parser class unescape: '') = ''.
	self assert: (parser class unescape: '\') = ''.
	self assert: (parser class unescape: '\\') = '\'.
	self assert: (parser class unescape: '\\\') = '\'.
	self assert: (parser class unescape: '\\\\') = '\\'! !

TestCase subclass: #PRObjectTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Pier-Tests-Core'!

PRObjectTest subclass: #PRCommandTest
	instanceVariableNames: 'kernel structure context command'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Pier-Tests-Command'!

PRCommandTest subclass: #PRAddCommandTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Pier-Tests-Command'!

!PRAddCommandTest class methodsFor: 'testing' stamp: 'lr 3/30/2007 22:22'!
isAbstract
	^ false! !

!PRAddCommandTest methodsFor: 'private' stamp: 'lr 3/30/2007 22:22'!
actualClass
	^ PRAddCommand! !

!PRAddCommandTest methodsFor: 'testing' stamp: 'lr 3/9/2006 11:31'!
testAddChild
	| child |
	self
		shouldnt: [ self command execute ]
		raise: PRStructureError.
	self assert: (self structure childrenDecoration
		includes: self command name).

	child := self structure childrenDecoration
		at: self command name.
	self assert: child name = self command name.
	self assert: child species = self command type! !

!PRAddCommandTest methodsFor: 'testing' stamp: 'lr 1/10/2007 10:49'!
testAddConflict
	self
		shouldnt: [ self command execute ]
		raise: PRConflictingNameError.
	self
		should: [ self command execute ]
		raise: PRConflictingNameError! !

!PRAddCommandTest methodsFor: 'testing' stamp: 'lr 1/31/2007 08:29'!
testUncheckedConflict
	self command execute.
	self command beUnchecked.
	self
		shouldnt: [ self command execute ]
		raise: PRConflictingNameError! !

!PRAddCommandTest methodsFor: 'testing-utilties' stamp: 'lr 1/15/2007 21:34'!
testUniqueTitle
	20 timesRepeat: [
		self
			shouldnt: [
				self structure addChild: (PRPage named: (self command
					uniqueName: 'foo' in: self structure)) ]
			raise: PRConflictingNameError ].
	#( 'foo' 'foo 2' 'foo 9' 'foo 10' 'foo 11' 'foo 20' ) do: [ :each |
		self assert: (self structure childrenDecoration includes: each) ]! !

!PRCommandTest class methodsFor: 'testing' stamp: 'lr 3/30/2007 22:22'!
isAbstract
	^ true! !

!PRCommandTest methodsFor: 'private' stamp: 'lr 3/30/2007 22:22'!
actualClass
	^ PRCommand! !

!PRCommandTest methodsFor: 'private' stamp: 'lr 2/24/2007 21:04'!
actualInstance
	^ self actualClass new! !

!PRCommandTest methodsFor: 'accessing' stamp: 'lr 3/9/2006 11:31'!
command
	^ command ifNil: [ command := self actualInstance ]! !

!PRCommandTest methodsFor: 'accessing' stamp: 'lr 3/9/2006 11:31'!
context
	^ context ifNil: [ context := self contextInstance ]! !

!PRCommandTest methodsFor: 'private' stamp: 'lr 2/24/2007 21:03'!
contextInstance
	^ PRContext kernel: self kernel structure: self structure command: self command! !

!PRCommandTest methodsFor: 'accessing' stamp: 'lr 3/9/2006 11:31'!
instance
	^ self command! !

!PRCommandTest methodsFor: 'accessing' stamp: 'lr 3/9/2006 11:31'!
kernel
	^ kernel ifNil: [ kernel := self kernelInstance ]! !

!PRCommandTest methodsFor: 'private' stamp: 'lr 3/9/2006 11:31'!
kernelInstance
	^ PRKernel new
		root: ((PRPage named: 'root')
			addChild: (PRPage named: 'folder');
			addChild: (self structure);
			yourself);
		yourself! !

!PRCommandTest methodsFor: 'running' stamp: 'lr 2/24/2007 21:08'!
setUp
	context := self contextInstance! !

!PRCommandTest methodsFor: 'accessing' stamp: 'lr 3/9/2006 11:31'!
structure
	^ structure ifNil: [ structure := self structureInstance ]! !

!PRCommandTest methodsFor: 'private' stamp: 'lr 1/15/2007 21:34'!
structureInstance
	^ PRPage named: 'command'! !

!PRCommandTest methodsFor: 'testing-accessing' stamp: 'lr 10/22/2007 22:17'!
testAnswer
	self assert: self command answer isNil.
	self command answer: self context.
	self deny: self command answer = self context! !

!PRCommandTest methodsFor: 'testing-accessing' stamp: 'lr 10/22/2007 22:06'!
testContext
	self assert: self command context notNil.
	context := self context command: self command.
	self assert: self command context = self context! !

!PRCommandTest methodsFor: 'testing-testing' stamp: 'lr 2/12/2007 19:07'!
testIsChecked
	self assert: self command isChecked.

	self command beUnchecked.
	self deny: self command isChecked.

	self command beChecked.
	self assert: self command isChecked! !

!PRCommandTest methodsFor: 'testing-testing' stamp: 'lr 3/9/2006 11:31'!
testIsLogged
	self assert: self command isLogged! !

!PRCommandTest methodsFor: 'testing-testing' stamp: 'lr 3/9/2006 11:31'!
testIsQuick
	self deny: self command isQuick! !

!PRCommandTest methodsFor: 'testing-testing' stamp: 'lr 3/9/2006 11:31'!
testIsView
	self deny: self command isView! !

!PRCommandTest methodsFor: 'testing-accessing' stamp: 'lr 3/9/2006 11:31'!
testKernel
	self assert: self command kernel = self kernel! !

!PRCommandTest methodsFor: 'testing-accessing' stamp: 'lr 3/9/2006 11:31'!
testRoot
	self assert: self command root = self kernel root! !

!PRCommandTest methodsFor: 'testing-accessing' stamp: 'lr 3/9/2006 11:31'!
testStructure
	self assert: self command structure = self structure! !

!PRCommandTest methodsFor: 'testing-accessing' stamp: 'lr 3/9/2006 11:31'!
testTimestamp
	| stamp |
	self assert: self command timestamp isNil.
	self command timestamp: (stamp := TimeStamp now).
	self assert: self command timestamp = stamp! !

!PRCommandTest methodsFor: 'testing-utilities' stamp: 'lr 2/12/2007 19:07'!
testUniqueName
	20 timesRepeat: [
		self
			shouldnt: [
				self structure addChild: (PRPage named: (self command
					uniqueName: 'foo' in: self structure)) ]
			raise: PRConflictingNameError ]! !

!PRCommandTest methodsFor: 'testing-utilities' stamp: 'lr 2/12/2007 19:07'!
testUniqueNameDoesNotAddDecoration
	self command uniqueName: 'foo' in: self structure.
	self structure
		decorationOfClass: self structure childrenDecorationClass
		ifAbsent: [ ^ self ].
	self assert: self structure hasChildren! !

!PRCommandTest methodsFor: 'testing-validating' stamp: 'lr 1/10/2007 10:49'!
testValidateChild
	self
		should: [
			self command
				validateChild: (PRPage named: 'folder')
				in: self context root ]
		raise: PRConflictingNameError.
	self
		shouldnt: [
			self command
				validateChild: (PRPage named: 'zork')
				in: self context root ]
		raise: PRConflictingNameError.
	self
		shouldnt: [
			self command
				validateChild: (self context root childrenDecoration at: 'folder')
				in: self context root ]
		raise: PRConflictingNameError! !

!PRCommandTest methodsFor: 'testing-validating' stamp: 'lr 1/15/2007 21:34'!
testValidateChildDoesNotAddDecoration
	self command
		validateChild: (PRPage named: 'zork')
		in: self context root.
	self structure
		decorationOfClass: self structure childrenDecoration
		ifAbsent: [ ^ self ].
	self assert: self structure hasChildren! !

!PRCommandTest methodsFor: 'testing-validating' stamp: 'lr 1/15/2007 21:34'!
testValidateChildNamed
	self
		should: [
			self command
				validateChild: PRPage new
				named: 'folder'
				in: self context root ]
		raise: PRConflictingNameError.
	self
		shouldnt: [
			self command
				validateChild: PRPage new
				named: 'zork'
				in: self context root ]
		raise: PRConflictingNameError.
	self
		shouldnt: [
			self command
				validateChild: (self context root childrenDecoration
					at: 'folder')
				named: 'zork'
				in: self context root ]
		raise: PRConflictingNameError! !

!PRCommandTest methodsFor: 'testing-validating' stamp: 'lr 1/10/2007 10:49'!
testValidateName
	self
		shouldnt: [
			self command
				validateName: 'zork'
				of: PRPage new
				in: self context root ]
		raise: PRConflictingNameError.
	self
		should: [
			self command
				validateName: 'folder'
				of: PRPage new
				in: self context root ]
		raise: PRConflictingNameError.
	self
		shouldnt: [
			self command
				validateName: 'zork'
				of: (self context root childrenDecoration at: 'folder')
				in: self context root ]
		raise: PRConflictingNameError.
	self
		shouldnt: [
			self command
				validateName: 'folder'
				of: (self context root childrenDecoration at: 'folder')
				in: self context root ]
		raise: PRConflictingNameError! !

!PRCommandTest methodsFor: 'testing-validating' stamp: 'lr 1/15/2007 21:34'!
testValidateNesting
	self
		shouldnt: [
			self command
				validateNestingOf: self context root
				in: PRPage new ]
		raise: PRInvalidNestingError.
	self
		shouldnt: [
			self command
				validateNestingOf: PRPage new
				in: self context root ]
		raise: PRInvalidNestingError! !

PRCommandTest subclass: #PREditCommandTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Pier-Tests-Command'!

!PREditCommandTest class methodsFor: 'testing' stamp: 'lr 3/30/2007 22:22'!
isAbstract
	^ false! !

!PREditCommandTest methodsFor: 'private' stamp: 'lr 3/30/2007 22:22'!
actualClass
	^ PREditCommand! !

!PREditCommandTest methodsFor: 'testing-title' stamp: 'lr 3/9/2006 11:31'!
testTitleChanged
	| title |
	self command
		write: (title := 'foo')
		using: PRStructure descriptionTitle.
	self
		shouldnt: [ self command execute ]
		raise: PRStructureError.
	self assert: self structure title = title! !

!PREditCommandTest methodsFor: 'testing-title' stamp: 'lr 3/9/2006 11:31'!
testTitleInitialized
	self assert: (self command readUsing: PRStructure descriptionTitle) = self structure title! !

!PREditCommandTest methodsFor: 'testing-title' stamp: 'lr 3/9/2006 11:31'!
testTitleUnchanged
	| title |
	title := self structure title.
	self
		shouldnt: [ self command execute ]
		raise: PRStructureError.
	self assert: self structure title = title! !

PREditCommandTest subclass: #PREditFileCommandTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Pier-Tests-Command'!

!PREditFileCommandTest class methodsFor: 'testing' stamp: 'lr 3/9/2006 11:31'!
isAbstract
	^ false! !

!PREditFileCommandTest methodsFor: 'private' stamp: 'lr 3/9/2006 11:31'!
structureInstance
	^ PRFile named: 'command'! !

!PREditFileCommandTest methodsFor: 'testing-file' stamp: 'lr 3/9/2006 11:31'!
testFileChanged
	| file |
	self command
		write: (file := MAFileModel new
			contents: 'foobar';
			filename: 'test.txt';
			mimetype: 'text/plain';
			yourself)
		using: PRFile descriptionFile.
	self
		shouldnt: [ self command execute ]
		raise: PRStructureError.
	self assert: self structure file = file! !

!PREditFileCommandTest methodsFor: 'testing-file' stamp: 'lr 3/9/2006 11:31'!
testFileInitialized
	self assert: (self command readUsing: PRFile descriptionFile) = self structure file! !

!PREditFileCommandTest methodsFor: 'testing-file' stamp: 'lr 3/9/2006 11:31'!
testFileUnchanged
	| file |
	file := self structure file.
	self
		shouldnt: [ self command execute ]
		raise: PRStructureError.
	self assert: self structure file = file! !

PREditCommandTest subclass: #PREditPageCommandTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Pier-Tests-Command'!

!PREditPageCommandTest class methodsFor: 'testing' stamp: 'lr 3/9/2006 11:31'!
isAbstract
	^ false! !

!PREditPageCommandTest methodsFor: 'private' stamp: 'lr 3/9/2006 11:31'!
structureInstance
	^ PRPage named: 'command'! !

!PREditPageCommandTest methodsFor: 'testing-contents' stamp: 'lr 10/18/2007 17:38'!
testContentsChanged
	| document |
	document := PRPage descriptionDocument
		fromString: '!!foo'.
	self command
		write: document
		using: PRPage descriptionDocument.
	self
		shouldnt: [ self command execute ]
		raise: PRStructureError.
	self assert: self structure document = document! !

!PREditPageCommandTest methodsFor: 'testing-contents' stamp: 'lr 10/18/2007 17:37'!
testContentsInitialized
	self assert: (self command readUsing: PRPage descriptionDocument) = self structure document! !

!PREditPageCommandTest methodsFor: 'testing-contents' stamp: 'lr 10/18/2007 17:38'!
testContentsUnchanged
	| document |
	document := self structure document.
	self
		shouldnt: [ self command execute ]
		raise: PRStructureError.
	self assert: self structure document = document! !

PRCommandTest subclass: #PRLocationCommandTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Pier-Tests-Command'!

PRLocationCommandTest subclass: #PRCopyCommandTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Pier-Tests-Command'!

!PRCopyCommandTest class methodsFor: 'testing' stamp: 'lr 3/30/2007 22:22'!
isAbstract
	^ false! !

!PRCopyCommandTest methodsFor: 'private' stamp: 'lr 3/30/2007 22:22'!
actualClass
	^ PRCopyCommand! !

!PRCopyCommandTest methodsFor: 'testing' stamp: 'lr 3/21/2006 18:43'!
testCopy
	self command name: 'foo'.
	self
		shouldnt: [ self command execute ]
		raise: PRStructureError.
	self assert: (self structure parent childrenDecoration
		includes: 'foo').
	self assert: (self structure parent childrenDecoration
		at: 'foo') = self command answer structure! !

!PRCopyCommandTest methodsFor: 'testing' stamp: 'lr 3/21/2006 18:43'!
testCopyIntoChild
	self command
		name: 'foo';
		target: self structure.
	self
		shouldnt: [ self command execute ]
		raise: PRStructureError.
	self assert: (self structure childrenDecoration
		includes: 'foo').
	self assert: (self structure childrenDecoration
		at: 'foo') = self command answer structure! !

!PRCopyCommandTest methodsFor: 'testing' stamp: 'lr 3/21/2006 18:43'!
testCopyIntoRoot
	self command
		name: 'foo';
		target: self command root.
	self
		shouldnt: [ self command execute ]
		raise: PRStructureError.
	self assert: (self command root childrenDecoration
		includes: 'foo').
	self assert: (self command root childrenDecoration
		at: 'foo') = self command answer structure! !

!PRCopyCommandTest methodsFor: 'testing' stamp: 'lr 4/10/2006 14:52'!
testCopyTitle
	self command name: 'foo'; execute.
	self assert: (self structure title) = 'Command'.
	self assert: (self structure parent childrenDecoration
		at: 'foo') title = 'Foo'! !

!PRCopyCommandTest methodsFor: 'testing' stamp: 'lr 3/9/2006 11:31'!
testInitialized
	super testInitialized.
	self assert: self structure name , ' copy' = self command name! !

!PRLocationCommandTest class methodsFor: 'testing' stamp: 'lr 3/30/2007 22:22'!
isAbstract
	^ true! !

!PRLocationCommandTest methodsFor: 'private' stamp: 'lr 3/30/2007 22:22'!
actualClass
	^ PRLocationCommand! !

!PRLocationCommandTest methodsFor: 'testing' stamp: 'lr 1/10/2007 10:50'!
testConflict
	self command name: 'folder'.
	self
		should: [ self command execute ]
		raise: PRConflictingNameError! !

!PRLocationCommandTest methodsFor: 'testing' stamp: 'lr 3/9/2006 11:31'!
testInitialized
	self assert: self command target = self structure parent! !

PRLocationCommandTest subclass: #PRMoveCommandTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Pier-Tests-Command'!

!PRMoveCommandTest class methodsFor: 'testing' stamp: 'lr 3/30/2007 22:22'!
isAbstract
	^ false! !

!PRMoveCommandTest methodsFor: 'private' stamp: 'lr 3/30/2007 22:22'!
actualClass
	^ PRMoveCommand! !

!PRMoveCommandTest methodsFor: 'testing' stamp: 'lr 3/9/2006 11:31'!
testInitialized
	super testInitialized.
	self assert: self structure name = self command name! !

!PRMoveCommandTest methodsFor: 'testing' stamp: 'lr 3/9/2006 11:31'!
testMove
	self command target: self command root.
	self
		shouldnt: [ self command execute ]
		raise: PRStructureError.
	self assert: (self command root childrenDecoration
		includes: self structure name)! !

!PRMoveCommandTest methodsFor: 'testing' stamp: 'lr 3/9/2006 11:31'!
testMoveIntoChild
	self command target: self structure.
	self
		should: [ self command execute ]
		raise: PRInvalidNestingError.
	self assert: (self structure parent childrenDecoration
		includes: self structure name)! !

!PRMoveCommandTest methodsFor: 'testing' stamp: 'lr 3/9/2006 11:31'!
testMoveIntoFolder
	self command target: (self command root childrenDecoration
		at: 'folder').
	self
		shouldnt: [ self command execute ]
		raise: PRStructureError.
	self deny: (self command root childrenDecoration
		includes: self structure name).
	self assert: ((self command root childrenDecoration
		at: 'folder') childrenDecoration
			includes: self structure name)! !

!PRMoveCommandTest methodsFor: 'testing' stamp: 'lr 3/9/2006 11:31'!
testRename
	self command name: 'foo'.
	self
		shouldnt: [ self command execute ]
		raise: PRConflictingNameError.
	self deny: (self structure parent childrenDecoration
		includes: 'command').
	self assert: (self structure parent childrenDecoration
		includes: 'foo')! !

!PRMoveCommandTest methodsFor: 'testing' stamp: 'lr 3/9/2006 11:31'!
testRenameExisting
	self command name: 'folder'.
	self
		should: [ self command execute ]
		raise: PRConflictingNameError.
	self assert: (self structure parent childrenDecoration
		includes: 'command').
	self assert: (self structure parent childrenDecoration
		includes: 'folder')! !

PRCommandTest subclass: #PRRemoveCommandTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Pier-Tests-Command'!

!PRRemoveCommandTest class methodsFor: 'testing' stamp: 'lr 3/30/2007 22:22'!
isAbstract
	^ false! !

!PRRemoveCommandTest methodsFor: 'private' stamp: 'lr 3/30/2007 22:22'!
actualClass
	^ PRRemoveCommand! !

!PRRemoveCommandTest methodsFor: 'testing-testing' stamp: 'lr 3/9/2006 11:31'!
testIsQuick
	self assert: self command isQuick! !

!PRRemoveCommandTest methodsFor: 'testing' stamp: 'lr 3/9/2006 11:31'!
testRemoveLeaf
	self assert: (self kernel root childrenDecoration
		includes: self structure name).
	self
		shouldnt: [ self command execute ]
		raise: PRStructureError.
	self assert: self structure parent isNil.
	self deny: (self kernel root childrenDecoration
		includes: self structure name)! !

!PRRemoveCommandTest methodsFor: 'testing' stamp: 'lr 3/9/2006 11:31'!
testRemoveNode
	self structure
		addChild: (PRPage named: 'foo');
		addChild: (PRPage named: 'bar').
	self assert: (self kernel root childrenDecoration
		includes: self structure name).
	self
		shouldnt: [ self command execute ]
		raise: PRStructureError.
	self assert: self structure parent isNil.
	self deny: (self kernel root childrenDecoration
		includes: self structure name)! !

!PRRemoveCommandTest methodsFor: 'testing' stamp: 'lr 3/5/2007 14:06'!
testRemoveRoot
	context := self context
		structure: self kernel root
		command: self actualClass new.
	self
		should: [ context command execute ]
		raise: PRStructureError! !

PRCommandTest subclass: #PRViewCommandTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Pier-Tests-Command'!

!PRViewCommandTest class methodsFor: 'testing' stamp: 'lr 3/30/2007 22:22'!
isAbstract
	^ false! !

!PRViewCommandTest methodsFor: 'private' stamp: 'lr 3/30/2007 22:22'!
actualClass
	^ PRViewCommand! !

!PRViewCommandTest methodsFor: 'testing-testing' stamp: 'lr 3/9/2006 11:31'!
testIsLogged
	self deny: self command isLogged! !

!PRViewCommandTest methodsFor: 'testing-testing' stamp: 'lr 3/9/2006 11:31'!
testIsView
	self assert: self command isView! !

!PRViewCommandTest methodsFor: 'testing' stamp: 'lr 3/9/2006 11:31'!
testSimple
	self
		should: [ self command execute ]
		raise: Error! !

PRObjectTest subclass: #PRContextTest
	instanceVariableNames: 'context'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Pier-Tests-Kernel'!

!PRContextTest class methodsFor: 'testing' stamp: 'lr 3/30/2007 22:22'!
isAbstract
	^ false! !

!PRContextTest methodsFor: 'private' stamp: 'lr 3/30/2007 22:22'!
actualClass
	^ PRContext! !

!PRContextTest methodsFor: 'accessing' stamp: 'lr 3/9/2006 11:31'!
context
	^ context ifNil: [ context := self contextInstance ]! !

!PRContextTest methodsFor: 'accessing' stamp: 'lr 3/9/2006 11:31'!
instance
	^ self context! !

!PRContextTest methodsFor: 'testing' stamp: 'lr 4/13/2007 14:53'!
testCommands
	self assert: (self context commands includes: self context command class)! !

!PRContextTest methodsFor: 'testing' stamp: 'lr 8/14/2007 23:51'!
testCopy
	| copy |
	copy := self context copy.
	self assert: self context command context == self context.
	self assert: copy command context == copy! !

!PRContextTest methodsFor: 'testing' stamp: 'lr 4/13/2007 14:57'!
testEnumerator
	| array |
	array := self context enumerator contents.
	self assert: array first name = 'folder'.
	self assert: array size = 1! !

!PRContextTest methodsFor: 'testing-navigation' stamp: 'lr 4/13/2007 14:59'!
testGotoCommand
	| current currentStructure currentCommand next nextCommand |
	currentStructure := self context structure.
	currentCommand := self context command.
	current := self context.

	nextCommand := self context structure editCommandClass new.
	next := self context command: nextCommand.
	self deny: current = next.

	self assert: current structure = currentStructure.
	self assert: current command = currentCommand.

	self assert: next structure = currentStructure.
	self assert: next command = nextCommand! !

!PRContextTest methodsFor: 'testing-navigation' stamp: 'lr 4/13/2007 14:59'!
testGotoStructure
	| current currentStructure currentCommand next nextStructure |
	currentStructure := self context structure.
	currentCommand := self context command.
	current := self context.

	nextStructure := self context structure childrenDecoration at: 'folder'.
	next := self context structure: nextStructure.
	self deny: current = next.

	self assert: current structure = currentStructure.
	self assert: current command = currentCommand.

	self assert: next structure = nextStructure.
	self assert: next command isView! !

!PRContextTest methodsFor: 'testing-navigation' stamp: 'lr 4/13/2007 15:00'!
testGotoStructureCommand
	| current currentStructure currentCommand next nextStructure nextCommand |
	currentStructure := self context structure.
	currentCommand := self context command.
	current := self context.

	nextStructure := self context structure childrenDecoration at: 'folder'.
	nextCommand := nextStructure editCommandClass new.
	next := self context structure: nextStructure command: nextCommand.
	self deny: current = next.

	self assert: current structure = currentStructure.
	self assert: current command = currentCommand.

	self assert: next structure = nextStructure.
	self assert: next command = nextCommand! !

!PRContextTest methodsFor: 'testing' stamp: 'lr 4/13/2007 14:52'!
testInitialState
	self assert: self context structure = self context root.
	self assert: self context command isView! !

PRObjectTest subclass: #PRDecoratedTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Pier-Tests-Structure'!

!PRDecoratedTest class methodsFor: 'testing' stamp: 'lr 3/30/2007 22:22'!
isAbstract
	^ true! !

!PRDecoratedTest methodsFor: 'private' stamp: 'lr 3/30/2007 22:22'!
actualClass
	^ PRDecorated! !

!PRDecoratedTest methodsFor: 'accessing' stamp: 'lr 3/9/2006 11:31'!
decorationWithPriority: anInteger
	^ PRMockDecoration new
		priority: anInteger;
		yourself! !

!PRDecoratedTest methodsFor: 'testing-adding' stamp: 'lr 3/5/2007 14:00'!
testAddDecoration
	| mock1 mock2 index1 index2 |
	mock1 := self decorationWithPriority: 10.
	mock2 := self decorationWithPriority: -5.

	self assert: (self instance addDecoration: mock1) = mock1.
	self assert: self instance = mock1 decorated.
	self assert: (self instance decorations includes: mock1).

	self assert: (self instance addDecoration: mock2) = mock2.
	self assert: self instance = mock2 decorated.
	self assert: (self instance decorations includes: mock2).

	index1 := self instance decorations indexOf: mock1.
	index2 := self instance decorations indexOf: mock2.
	self assert: index1 > index2.

	self should: [ self instance addDecoration: mock1 ] raise: PRDecorationError.
	self should: [ self instance addDecoration: mock2 ] raise: PRDecorationError.
	self assert: (self instance decorations includes: mock2).
	self assert: (self instance decorations includes: mock2)! !

!PRDecoratedTest methodsFor: 'testing-adding' stamp: 'lr 3/9/2006 11:31'!
testAddDecorationIfPresent
	| mock1 mock2 index1 index2 |
	mock1 := self decorationWithPriority: 10.
	mock2 := self decorationWithPriority: -5.

	self assert: (self instance
		addDecoration: mock1
		ifPresent: [ :value | self assert: false ]) = mock1.
	self assert: self instance = mock1 decorated.
	self assert: (self instance decorations includes: mock1).

	self assert: (self instance
		addDecoration: mock2
		ifPresent: [ :value | self assert: false ]) = mock2.
	self assert: self instance = mock2 decorated.
	self assert: (self instance decorations includes: mock2).

	index1 := self instance decorations indexOf: mock1.
	index2 := self instance decorations indexOf: mock2.
	self assert: index1 > index2.

	self assert: (self instance
		addDecoration: mock1
		ifPresent: [ :value | nil ]) isNil.
	self assert: (self instance
		addDecoration: mock2
		ifPresent: [ :value | nil ]) isNil.
	self assert: (self instance decorations includes: mock1).
	self assert: (self instance decorations includes: mock2)! !

!PRDecoratedTest methodsFor: 'testing-copying' stamp: 'lr 3/9/2006 11:31'!
testCopyDecorations
	| decoration copiedInstance copiedDecoration |
	decoration := self instance addDecoration: (self decorationWithPriority: SmallInteger minVal).
	copiedInstance := self instance copy.
	copiedDecoration := copiedInstance decorations first.

	self deny: self instance == copiedInstance.
	self deny: decoration == copiedDecoration.

	self assert: self instance decorations first = decoration.
	self assert: self instance = decoration decorated.

	self assert: copiedInstance decorations first = copiedDecoration.
	self assert: copiedInstance = copiedDecoration decorated! !

!PRDecoratedTest methodsFor: 'testing-querying' stamp: 'lr 3/5/2007 14:00'!
testDecorationOfClass
	| mock |
	self should: [ self instance decorationOfClass: PRMockDecoration ] raise: PRDecorationError.
	self instance addDecoration: (mock := self decorationWithPriority: 1).
	self assert: (self instance decorationOfClass: PRMockDecoration) = mock! !

!PRDecoratedTest methodsFor: 'testing-querying' stamp: 'lr 3/9/2006 11:31'!
testDecorationOfClassIfAbsent
	| mock |
	self assert: (self instance decorationOfClass: PRMockDecoration ifAbsent: [ nil ]) isNil.
	self instance addDecoration: (mock := self decorationWithPriority: 1).
	self assert: (self instance decorationOfClass: PRMockDecoration) = mock! !

!PRDecoratedTest methodsFor: 'testing-enumerating' stamp: 'lr 3/9/2006 11:31'!
testDecorationsDo
	| first second |
	self instance
		addDecoration: (first := self decorationWithPriority: SmallInteger minVal);
		addDecoration: (second := self decorationWithPriority: SmallInteger maxVal).
	self instance decorationsDo: [ :each |
		(first notNil and: [ second notNil and: [ each = first ] ])
			ifTrue: [ first := nil ].
		(first isNil and: [ second notNil and: [ each = second ] ])
			ifTrue: [ second := nil ] ].
	self assert: first isNil.
	self assert: second isNil! !

!PRDecoratedTest methodsFor: 'testing-enumerating' stamp: 'lr 3/9/2006 11:31'!
testDecorationsDoOwnerDo
	| instance first second |
	instance := self instance
		addDecoration: (first := self decorationWithPriority: SmallInteger minVal);
		addDecoration: (second := self decorationWithPriority: SmallInteger maxVal);
		yourself.
	self instance
		decorationsDo: [ :each |
			(first notNil and: [ instance notNil and: [ second notNil and: [ each = first ] ] ])
				ifTrue: [ first := nil ].
			(first isNil and: [ instance isNil and: [ second notNil and: [ each = second ] ] ])
				ifTrue: [ second := nil ] ]
		ownerDo: [ :each |
			self assert: first isNil.
			self assert: second notNil.
			self assert: instance notNil.
			instance := nil ].
	self assert: first isNil.
	self assert: second isNil.
	self assert: instance isNil! !

!PRDecoratedTest methodsFor: 'testing' stamp: 'lr 3/9/2006 11:31'!
testInitialized
	self assert: (self instance decorations isKindOf: Collection)! !

!PRDecoratedTest methodsFor: 'testing-removing' stamp: 'lr 3/5/2007 14:00'!
testRemoveDecoration
	| mock1 mock2 |
	self instance
		addDecoration: (mock1 := self decorationWithPriority: 1);
		addDecoration: (mock2 := self decorationWithPriority: 2).

	self assert: (self instance removeDecoration: mock1) = mock1.
	self deny: (self instance decorations includes: mock1).
	self assert: (self instance decorations includes: mock2).

	self assert: (self instance removeDecoration: mock2) = mock2.
	self deny: (self instance decorations includes: mock1).
	self deny: (self instance decorations includes: mock2).

	self should: [ self instance removeDecoration: mock2 ] raise: PRDecorationError! !

!PRDecoratedTest methodsFor: 'testing-removing' stamp: 'lr 3/9/2006 11:31'!
testRemoveDecorationIfAbsent
| mock1 mock2 |
	self instance
		addDecoration: (mock1 := self decorationWithPriority: 1);
		addDecoration: (mock2 := self decorationWithPriority: 2).

	self assert: (self instance removeDecoration: mock1 ifAbsent: [ nil ]) = mock1.
	self deny: (self instance decorations includes: mock1).
	self assert: (self instance decorations includes: mock2).

	self assert: (self instance removeDecoration: mock2 ifAbsent: [ nil ]) = mock2.
	self deny: (self instance decorations includes: mock1).
	self deny: (self instance decorations includes: mock2).

	self assert: (self instance removeDecoration: mock2 ifAbsent: [ nil ]) isNil! !

PRDecoratedTest subclass: #PRStructureTest
	instanceVariableNames: 'root folder child structure'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Pier-Tests-Structure'!

PRStructureTest subclass: #PRCaseTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Pier-Tests-Structure'!

!PRCaseTest class methodsFor: 'testing' stamp: 'lr 3/30/2007 22:22'!
isAbstract
	^ true! !

!PRCaseTest methodsFor: 'private' stamp: 'lr 3/30/2007 22:22'!
actualClass
	^ PRCase! !

!PRCaseTest methodsFor: 'private' stamp: 'lr 10/18/2007 17:45'!
actualInstance
	^ super actualInstance
		contents: '!!A Title
-A simple List-Element';
		yourself
! !

!PRCaseTest methodsFor: 'testing' stamp: 'lr 10/18/2007 17:45'!
testContents
	self structure contents: nil.
	self assert: self structure contents = ''.

	self structure contents: ''.
	self assert: self structure contents = ''.

	self structure contents: 'Foo'.
	self assert: self structure contents = 'Foo'! !

!PRCaseTest methodsFor: 'testing' stamp: 'lr 4/13/2007 15:27'!
testDocument
	self structure document: PRDocument new.
	self assert: self structure document = PRDocument new.
	self assert: self structure contents = ''.
	
	structure := self actualClass new.
	self assert: structure document = structure defaultDocument! !

!PRCaseTest methodsFor: 'testing-visiting' stamp: 'lr 2/12/2007 19:07'!
testFullTextSearch
	| matches |
	matches := self root fullTextSearch
		subString: 'title';
		caseSensitive: true;
		contents.
	self assert: matches size = 0.

	matches := self root fullTextSearch
		subString: 'Title';
		caseSensitive: true;
		contents.
	self assert: matches size = 1.
	self assert: matches first = self structure.

	matches := self root fullTextSearch
		subString: 'title';
		caseSensitive: false;
		contents.
	self assert: matches size = 1.
	self assert: matches first = self structure.

	matches := self root fullTextSearch
		subString: 'list-element';
		caseSensitive: true;
		contents.
	self assert: matches size = 0.

	matches := self root fullTextSearch
		subString: 'List-Element';
		caseSensitive: true;
		contents.
	self assert: matches size = 1.
	self assert: matches first = self structure.

	matches := self root fullTextSearch
		subString: 'list-element';
		caseSensitive: false;
		contents.
	self assert: matches size = 1.
	self assert: matches first = self structure! !

!PRCaseTest methodsFor: 'testing-testing' stamp: 'lr 4/13/2007 15:27'!
testHasDocument
	self assert: self structure hasDocument! !

!PRCaseTest methodsFor: 'testing-visiting' stamp: 'lr 2/12/2007 19:07'!
testIncomingReferences
	| matches |
	matches := self root incomingReferences
		to: self structure;
		collect: [ :each | each owner ].
	self assert: matches size = 0.

	self root contents: '*/folder/structure*'.
	matches := self root incomingReferences
		to: self structure;
		collect: [ :each | each owner ].
	self assert: matches size = 1.
	self assert: matches first = self root.

	self folder contents: '+/folder/structure+'.
	matches := self root incomingReferences
		to: self structure;
		collect: [ :each | each owner ].
	self assert: matches size = 2.
	self assert: matches first = self root.
	self assert: matches second = self folder! !

!PRCaseTest methodsFor: 'testing-visiting' stamp: 'lr 2/12/2007 19:07'!
testOutgoingReferences
	| matches |
	self structure contents: ''.
	matches := self structure outgoingReferences
		collect: [ :each | each target ].
	self assert: matches size = 0.

	self structure contents: '*/*'.
	matches := self structure outgoingReferences
		collect: [ :each | each target ].
	self assert: matches size = 1.
	self assert: matches first = self root.

	self structure contents: '*.*'.
	matches := self structure outgoingReferences
		collect: [ :each | each target ].
	self assert: matches size = 1.
	self assert: matches first = self structure.

	self structure contents: '*.* */* */*'.
	matches := self structure outgoingReferences
		collect: [ :each | each target ].
	self assert: matches size = 3.
	self assert: matches first = self structure.
	self assert: matches second = self root.
	self assert: matches third = self root! !

PRCaseTest subclass: #PRPageTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Pier-Tests-Structure'!

!PRPageTest class methodsFor: 'testing' stamp: 'lr 3/30/2007 22:22'!
isAbstract
	^ false! !

!PRPageTest methodsFor: 'private' stamp: 'lr 3/30/2007 22:22'!
actualClass
	^ PRPage! !

PRStructureTest subclass: #PRFileTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Pier-Tests-Structure'!

!PRFileTest class methodsFor: 'testing' stamp: 'lr 3/30/2007 22:22'!
isAbstract
	^ false! !

!PRFileTest methodsFor: 'private' stamp: 'lr 3/30/2007 22:22'!
actualClass
	^ PRFile! !

!PRFileTest methodsFor: 'testing' stamp: 'lr 4/13/2007 15:29'!
testFile
	| model |
	self assert: self structure file isNil.
	model := MAMemoryFileModel new.
	self structure file: model.
	self assert: self structure file = model! !

!PRStructureTest class methodsFor: 'testing' stamp: 'lr 3/30/2007 22:22'!
isAbstract
	^ true! !

!PRStructureTest methodsFor: 'private' stamp: 'lr 3/30/2007 22:22'!
actualClass
	^ PRStructure! !

!PRStructureTest methodsFor: 'private' stamp: 'lr 3/9/2006 11:31'!
actualInstance
	^ self actualClass named: 'structure'! !

!PRStructureTest methodsFor: 'accessing' stamp: 'lr 3/9/2006 11:31'!
child
	^ child! !

!PRStructureTest methodsFor: 'private' stamp: 'lr 10/30/2006 16:41'!
childInstance
	^ PRPage named: 'child'! !

!PRStructureTest methodsFor: 'utilities' stamp: 'lr 9/25/2007 09:15'!
enumerator: aVisitor gives: aCollection
	| children |
	children := aVisitor collect: [ :each | each name ].
	self
		assert: children = aCollection
		description: children asString , ' should be ' , aCollection asString
		resumable: true! !

!PRStructureTest methodsFor: 'accessing' stamp: 'lr 3/9/2006 11:31'!
folder
	^ folder! !

!PRStructureTest methodsFor: 'private' stamp: 'lr 10/30/2006 16:41'!
folderInstance
	^ PRPage named: 'folder'! !

!PRStructureTest methodsFor: 'accessing' stamp: 'lr 3/9/2006 11:31'!
instance
	^ structure! !

!PRStructureTest methodsFor: 'accessing' stamp: 'lr 3/9/2006 11:31'!
root
	^ root! !

!PRStructureTest methodsFor: 'private' stamp: 'lr 10/30/2006 16:41'!
rootInstance
	^ PRPage named: 'root'! !

!PRStructureTest methodsFor: 'running' stamp: 'lr 3/9/2006 11:31'!
setUp
	root := self rootInstance.
	folder := self folderInstance.
	child := self childInstance.
	structure := self actualInstance.

	self root addChild: self folder.
	self folder addChild: self child.
	self folder addChild: self structure! !

!PRStructureTest methodsFor: 'accessing' stamp: 'lr 3/9/2006 11:31'!
structure
	^ structure! !

!PRStructureTest methodsFor: 'testing-testing' stamp: 'lr 3/9/2006 11:31'!
testCanBeChildOf
	PRStructure withAllConcreteClassesDo: [ :each |
		self
			shouldnt: [ self structure canBeChildOf: each new ]
			raise: Error ]! !

!PRStructureTest methodsFor: 'testing-testing' stamp: 'lr 3/9/2006 11:31'!
testCanBeParentOf
	PRStructure withAllConcreteClassesDo: [ :each |
		self
			shouldnt: [ self structure canBeParentOf: each new ]
			raise: Error ]! !

!PRStructureTest methodsFor: 'testing-accessing' stamp: 'lr 4/13/2007 15:15'!
testCommands
	self assert: (self structure viewCommandClass includesBehavior: PRCommand).
	self assert: (self structure editCommandClass includesBehavior: PRCommand)! !

!PRStructureTest methodsFor: 'testing-copying' stamp: 'lr 3/21/2006 18:43'!
testCopyChildren
	| folderCopy childCopy structureCopy |
	folderCopy := self folder copy.
	childCopy := folderCopy childrenDecoration at: 'child'.
	structureCopy := folderCopy childrenDecoration at: 'structure'.

	self deny: self folder = folderCopy.
	self deny: self child = childCopy.
	self deny: self structure = structureCopy.

	self assert: self folder parent = self root.
	self assert: self child parent = self folder.
	self assert: self structure parent = self folder.

	self assert: folderCopy parent isNil.
	self assert: childCopy parent = folderCopy.
	self assert: structureCopy parent = folderCopy! !

!PRStructureTest methodsFor: 'testing-enumerator' stamp: 'lr 9/27/2007 10:05'!
testEnumerator
	self enumerator: self root enumerator gives: #( 'folder' ).
	self enumerator: self root enumerator with gives: #( 'root' 'folder' ).
	self enumerator: self root enumerator all gives: #( 'folder' 'child' 'structure' ).
	self enumerator: self root enumerator with all gives: #( 'root' 'folder' 'child' 'structure' ).
	self enumerator: self root enumerator everything gives: #( 'root' 'folder' 'child' 'structure' )! !

!PRStructureTest methodsFor: 'testing-testing' stamp: 'lr 3/9/2006 11:31'!
testHasChildren
	self assert: self root hasChildren.
	self assert: self folder hasChildren.
	self deny: self child hasChildren.
	self deny: self structure hasChildren! !

!PRStructureTest methodsFor: 'testing-testing' stamp: 'lr 4/13/2007 15:18'!
testHasDocument
	self assert: self root hasDocument.
	self assert: self folder hasDocument.
	self assert: self child hasDocument! !

!PRStructureTest methodsFor: 'testing-testing' stamp: 'lr 3/9/2006 11:31'!
testHasParent
	self deny: self root hasParent.
	self assert: self folder hasParent.
	self assert: self child hasParent.
	self assert: self structure hasParent! !

!PRStructureTest methodsFor: 'testing-lookup' stamp: 'lr 3/21/2006 18:43'!
testIncompleteLookup
	| lookup |
	lookup := PRIncompletePathLookup
		start: self root
		path: '/folder/zork'.
	self assert: lookup key = self folder.
	self assert: lookup value = 'zork'.

	lookup := PRIncompletePathLookup
		start: self structure
		path: '../structure/bar'.
	self assert: lookup key = self structure.
	self assert: lookup value = 'bar'! !

!PRStructureTest methodsFor: 'testing-lookup' stamp: 'lr 3/9/2006 11:31'!
testIncompleteLookupIgnored
	| lookup |
	lookup := PRIncompletePathLookup
		start: self folder
		path: '../folder/child/foo/bar'.
	self assert: lookup key = self child.
	self assert: lookup value = 'foo'.

	lookup := PRIncompletePathLookup
		start: self folder
		path: 'foo/bar'.
	self assert: lookup key = self folder.
	self assert: lookup value = 'foo'! !

!PRStructureTest methodsFor: 'testing-lookup' stamp: 'lr 3/21/2006 18:43'!
testIncompleteLookupTitle
	| lookup |
	lookup := PRIncompletePathLookup
		start: self root
		path: '/Folder/Zork'.
	self assert: lookup key = self folder.
	self assert: lookup value = 'Zork'.

	lookup := PRIncompletePathLookup
		start: self structure
		path: '../Structure/Bar'.
	self assert: lookup key = self structure.
	self assert: lookup value = 'Bar'! !

!PRStructureTest methodsFor: 'testing-testing' stamp: 'lr 3/9/2006 11:31'!
testIsAncestorOf
	self assert: (self root isAncestorOf: self root).
	self assert: (self root isAncestorOf: self folder).
	self assert: (self root isAncestorOf: self child).
	self assert: (self root isAncestorOf: self structure).

	self deny: (self folder isAncestorOf: self root).
	self assert: (self folder isAncestorOf: self folder).
	self assert: (self folder isAncestorOf: self child).
	self assert: (self folder isAncestorOf: self structure).

	self deny: (self child isAncestorOf: self root).
	self deny: (self child isAncestorOf: self folder).
	self assert: (self child isAncestorOf: self child).
	self deny: (self child isAncestorOf: self structure).

	self deny: (self structure isAncestorOf: self root).
	self deny: (self structure isAncestorOf: self folder).
	self deny: (self structure isAncestorOf: self child).
	self assert: (self structure isAncestorOf: self structure)! !

!PRStructureTest methodsFor: 'testing-testing' stamp: 'lr 3/9/2006 11:31'!
testIsRoot
	self assert: self root isRoot.
	self deny: self folder isRoot.
	self deny: self child isRoot.
	self deny: self structure isRoot! !

!PRStructureTest methodsFor: 'testing-accessing' stamp: 'lr 3/9/2006 11:31'!
testLevel
	self assert: self root level = 1.
	self assert: self folder level = 2.
	self assert: self child level = 3.
	self assert: self structure level = 3! !

!PRStructureTest methodsFor: 'testing-lookup' stamp: 'lr 3/9/2006 11:31'!
testLookupComposed
	self assert: (PRPathLookup start: self child path: '../child/..') = self folder.
	self assert: (PRPathLookup start: self child path: '../child/../') = self folder.

	self assert: (PRPathLookup start: self child path: '../structure/..') = self folder.
	self assert: (PRPathLookup start: self child path: '../structure/../') = self folder.

	self assert: (PRPathLookup start: self child path: '../structure/../child') = self child.
	self assert: (PRPathLookup start: self child path: '../structure/../child/') = self child.

	self assert: (PRPathLookup start: self child path: '../structure/../structure') = self structure.
	self assert: (PRPathLookup start: self child path: '../structure/../structure/') = self structure! !

!PRStructureTest methodsFor: 'testing-lookup' stamp: 'lr 3/9/2006 15:26'!
testLookupComposedTitle
	self assert: (PRPathLookup start: self child path: '../Child/..') = self folder.
	self assert: (PRPathLookup start: self child path: '../Child/../') = self folder.

	self assert: (PRPathLookup start: self child path: '../Structure/..') = self folder.
	self assert: (PRPathLookup start: self child path: '../Structure/../') = self folder.

	self assert: (PRPathLookup start: self child path: '../Structure/../child') = self child.
	self assert: (PRPathLookup start: self child path: '../structure/../Child/') = self child.

	self assert: (PRPathLookup start: self child path: '../Structure/../structure') = self structure.
	self assert: (PRPathLookup start: self child path: '../structure/../Structure/') = self structure! !

!PRStructureTest methodsFor: 'testing-lookup' stamp: 'lr 3/9/2006 11:31'!
testLookupEmpty
	self assert: (PRPathLookup start: self root path: '') = self root.
	self assert: (PRPathLookup start: self folder path: '') = self folder.
	self assert: (PRPathLookup start: self child path: '') = self child.
	self assert: (PRPathLookup start: self structure path: '') = self structure! !

!PRStructureTest methodsFor: 'testing-lookup' stamp: 'lr 3/5/2007 14:06'!
testLookupError
	self should: [ PRPathLookup start: self root path: 'unknown' ] raise: PRChildNotFoundError.
	self should: [ PRPathLookup start: self root path: 'unknown/' ] raise: PRChildNotFoundError.

	self should: [ PRPathLookup start: self root path: 'folDer' ] raise: PRChildNotFoundError.
	self should: [ PRPathLookup start: self root path: 'fOlder/' ] raise: PRChildNotFoundError.

	self should: [ PRPathLookup start: self root path: 'folder/unknown' ] raise: PRChildNotFoundError.
	self should: [ PRPathLookup start: self root path: 'folder/unknown/' ] raise: PRChildNotFoundError.

	self should: [ PRPathLookup start: self root path: 'folder/unknown/unknown' ] raise: PRChildNotFoundError.
	self should: [ PRPathLookup start: self root path: 'folder/unknown/unknown/' ] raise: PRChildNotFoundError.

	self should: [ PRPathLookup start: self root path: 'folder/instance/unknown' ] raise: PRChildNotFoundError.
	self should: [ PRPathLookup start: self root path: 'folder/instance/unknown/' ] raise: PRChildNotFoundError! !

!PRStructureTest methodsFor: 'testing-lookup' stamp: 'lr 3/9/2006 11:31'!
testLookupParent
	self assert: (PRPathLookup start: self root path: '..') = self root.
	self assert: (PRPathLookup start: self root path: '../') = self root.

	self assert: (PRPathLookup start: self folder path: '..') = self root.
	self assert: (PRPathLookup start: self folder path: '../') = self root.

	self assert: (PRPathLookup start: self child path: '..') = self folder.
	self assert: (PRPathLookup start: self child path: '../') = self folder.

	self assert: (PRPathLookup start: self structure path: '..') = self folder.
	self assert: (PRPathLookup start: self structure path: '../') = self folder! !

!PRStructureTest methodsFor: 'testing-lookup' stamp: 'lr 3/9/2006 11:31'!
testLookupParentParent
	self assert: (PRPathLookup start: self root path: '../..') = self root.
	self assert: (PRPathLookup start: self root path: '../../') = self root.

	self assert: (PRPathLookup start: self folder path: '../..') = self root.
	self assert: (PRPathLookup start: self folder path: '../../') = self root.

	self assert: (PRPathLookup start: self child path: '../..') = self root.
	self assert: (PRPathLookup start: self child path: '../../') = self root.

	self assert: (PRPathLookup start: self structure path: '../..') = self root.
	self assert: (PRPathLookup start: self structure path: '../..') = self root! !

!PRStructureTest methodsFor: 'testing-lookup' stamp: 'lr 3/9/2006 11:31'!
testLookupParsing
	self assert: (PRPathLookup new stream: 'abc' readStream; readNext) = 'abc'.
	self assert: (PRPathLookup new stream: 'abc/' readStream; readNext) = 'abc'.

	self assert: (PRPathLookup new stream: 'abc/def' readStream; readNext) = 'abc'.
	self assert: (PRPathLookup new stream: 'abc/def/' readStream; readNext) = 'abc'.

	self assert: (PRPathLookup new stream: 'abc' readStream; readNext; readNext) = ''.
	self assert: (PRPathLookup new stream: 'abc/' readStream; readNext; readNext) = ''.

	self assert: (PRPathLookup new stream: 'abc/def' readStream; readNext; readNext) = 'def'.
	self assert: (PRPathLookup new stream: 'abc/def/' readStream; readNext; readNext) = 'def'! !

!PRStructureTest methodsFor: 'testing-lookup' stamp: 'lr 3/9/2006 11:31'!
testLookupRelative
	self assert: (PRPathLookup start: self structure path: '../structure') = self structure.
	self assert: (PRPathLookup start: self structure path: '../structure/') = self structure.

	self assert: (PRPathLookup start: self structure path: '../../folder') = self folder.
	self assert: (PRPathLookup start: self structure path: '../../folder/') = self folder.

	self assert: (PRPathLookup start: self structure path: '../../folder/structure') = self structure.
	self assert: (PRPathLookup start: self structure path: '../../folder/structure/') = self structure! !

!PRStructureTest methodsFor: 'testing-lookup' stamp: 'lr 3/9/2006 15:24'!
testLookupRelativeTitle
	self assert: (PRPathLookup start: self structure path: '../Structure') = self structure.
	self assert: (PRPathLookup start: self structure path: '../Structure/') = self structure.

	self assert: (PRPathLookup start: self structure path: '../../Folder') = self folder.
	self assert: (PRPathLookup start: self structure path: '../../Folder/') = self folder.

	self assert: (PRPathLookup start: self structure path: '../../Folder/Structure') = self structure.
	self assert: (PRPathLookup start: self structure path: '../../Folder/Structure/') = self structure! !

!PRStructureTest methodsFor: 'testing-lookup' stamp: 'lr 3/9/2006 11:31'!
testLookupRoot
	self assert: (PRPathLookup start: self root path: '/') = self root.
	self assert: (PRPathLookup start: self root path: '/folder') = self folder.
	self assert: (PRPathLookup start: self root path: '/folder/child') = self child.
	self assert: (PRPathLookup start: self root path: '/folder/structure') = self structure.

	self assert: (PRPathLookup start: self structure path: '/') = self root.
	self assert: (PRPathLookup start: self structure path: '/folder') = self folder.
	self assert: (PRPathLookup start: self structure path: '/folder/child') = self child.
	self assert: (PRPathLookup start: self structure path: '/folder/structure') = self structure! !

!PRStructureTest methodsFor: 'testing-lookup' stamp: 'lr 3/9/2006 15:24'!
testLookupRootTitle
	self assert: (PRPathLookup start: self root path: '/Folder') = self folder.
	self assert: (PRPathLookup start: self root path: '/Folder/Child') = self child.
	self assert: (PRPathLookup start: self root path: '/Folder/Structure') = self structure.

	self assert: (PRPathLookup start: self structure path: '/Folder') = self folder.
	self assert: (PRPathLookup start: self structure path: '/Folder/Child') = self child.
	self assert: (PRPathLookup start: self structure path: '/Folder/Structure') = self structure! !

!PRStructureTest methodsFor: 'testing-accessing' stamp: 'lr 3/9/2006 11:31'!
testName
	self assert: self root name = 'root'.
	self assert: self folder name = 'folder'.
	self assert: self child name = 'child'.
	self assert: self structure name = 'structure'! !

!PRStructureTest methodsFor: 'testing-accessing' stamp: 'lr 3/9/2006 11:31'!
testParent
	self assert: self root parent = nil.
	self assert: self folder parent = root.
	self assert: self child parent = folder.
	self assert: self structure parent = folder! !

!PRStructureTest methodsFor: 'testing-accessing' stamp: 'lr 3/9/2006 11:31'!
testParents
	self assert: self root parents size = 1.
	self assert: self root parents first = self root.

	self assert: self folder parents size = 2.
	self assert: self folder parents first = self root.
	self assert: self folder parents second = self folder.

	self assert: self child parents size = 3.
	self assert: self child parents first = self root.
	self assert: self child parents second = self folder.
	self assert: self child parents third = self child.

	self assert: self structure parents size = 3.
	self assert: self structure parents first = self root.
	self assert: self structure parents second = self folder.
	self assert: self structure parents third = self structure! !

!PRStructureTest methodsFor: 'testing-reference' stamp: 'lr 9/27/2007 09:48'!
testReferenceEmpty
	self assert: (PRPathReference from: self root to: self root) = '.'.

	self assert: (PRPathReference from: self folder to: self folder) = '.'.
	self assert: (PRPathReference from: self child to: self child) = '.'.
	self assert: (PRPathReference from: self structure to: self structure) = '.'! !

!PRStructureTest methodsFor: 'testing-reference' stamp: 'lr 3/5/2007 14:10'!
testReferenceError
	self should: [ PRPathReference from: self root to: PRPage new ] raise: PRInvalidKernelError.
	self should: [ PRPathReference from: self folder to: PRPage new ] raise: PRInvalidKernelError.
	self should: [ PRPathReference from: self child to: PRPage new ] raise: PRInvalidKernelError.
	self should: [ PRPathReference from: self structure to: PRPage new ] raise: PRInvalidKernelError.

	self should: [ PRPathReference from: PRPage new to: self root  ] raise: PRInvalidKernelError.
	self should: [ PRPathReference from: PRPage new to: self folder ] raise: PRInvalidKernelError.
	self should: [ PRPathReference from: PRPage new to: self child ] raise: PRInvalidKernelError.
	self should: [ PRPathReference from: PRPage new to: self structure ] raise: PRInvalidKernelError! !

!PRStructureTest methodsFor: 'testing-reference' stamp: 'lr 3/9/2006 11:31'!
testReferenceParent
	self assert: (PRPathReference from: self folder to: self root) = '..'.
	self assert: (PRPathReference from: self child to: self folder) = '..'.
	self assert: (PRPathReference from: self structure to: self folder) = '..'.

	self assert: (PRPathReference from: self child to: self root) = '../..'.
	self assert: (PRPathReference from: self structure to: self root) = '../..'! !

!PRStructureTest methodsFor: 'testing-reference' stamp: 'lr 3/9/2006 11:31'!
testReferenceRelative
	self assert: (PRPathReference from: self child to: self structure) = '../structure'.
	self assert: (PRPathReference from: self structure to: self child) = '../child'! !

!PRStructureTest methodsFor: 'testing-reference' stamp: 'lr 9/27/2007 09:47'!
testReferenceRoot
	self assert: (PRPathReference to: self root) = '.'.
	self assert: (PRPathReference to: self folder) = 'folder'.
	self assert: (PRPathReference to: self child) = 'folder/child'.
	self assert: (PRPathReference to: self structure) = 'folder/structure'.

	self assert: (PRPathReference from: self root to: self root) = '.'.
	self assert: (PRPathReference from: self root to: self folder) = 'folder'.
	self assert: (PRPathReference from: self root to: self child) = 'folder/child'.
	self assert: (PRPathReference from: self root to: self structure) = 'folder/structure'! !

!PRStructureTest methodsFor: 'testing-accessing' stamp: 'lr 3/9/2006 11:31'!
testRoot
	self assert: self root root = self root.
	self assert: self folder root = self root.
	self assert: self child root = self root.
	self assert: self structure root = self root! !

!PRStructureTest methodsFor: 'testing-accessing' stamp: 'lr 5/28/2007 16:31'!
testTags
	self assert: self structure tags isEmpty.
	self structure tags: #( 'foo' 'bar' ).
	self assert: (self structure tags includes: 'foo').
	self assert: (self structure tags includes: 'bar')! !

PRObjectTest subclass: #PRDecorationTest
	instanceVariableNames: 'decorated decoration'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Pier-Tests-Structure'!

PRDecorationTest subclass: #PRChildrenTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Pier-Tests-Structure'!

!PRChildrenTest class methodsFor: 'testing' stamp: 'lr 3/30/2007 22:22'!
isAbstract
	^ false! !

!PRChildrenTest methodsFor: 'private' stamp: 'lr 3/30/2007 22:22'!
actualClass
	^ PRChildren! !

!PRChildrenTest methodsFor: 'private' stamp: 'lr 3/9/2006 11:31'!
firstChildInstance
	^ PRPage named: 'child1'! !

!PRChildrenTest methodsFor: 'private' stamp: 'lr 3/9/2006 11:31'!
secondChildInstance
	^ PRPage named: 'child2'! !

!PRChildrenTest methodsFor: 'testing-actions' stamp: 'lr 3/9/2006 11:31'!
testAdd
	| child1 child2 |
	child1 := self firstChildInstance.
	self assert: (self decoration add: child1) = child1.
	self assert: self decorated = child1 parent.

	child2 := self secondChildInstance.
	self assert: (self decoration add: child2) = child2.
	self assert: self decorated = child2 parent! !

!PRChildrenTest methodsFor: 'testing-accessing' stamp: 'lr 3/9/2006 11:31'!
testAt
	| child1 child2 |
	self decoration
		add: (child1 := self firstChildInstance);
		add: (child2 := self secondChildInstance).

	self assert: (self decoration at: child1 name) = child1.
	self assert: (self decoration at: child2 name) = child2.
	self should: [ self decoration at: 'zork' ] raise: Error! !

!PRChildrenTest methodsFor: 'testing-accessing' stamp: 'lr 3/9/2006 11:31'!
testAtIfAbsent
	| child1 child2 |
	self decoration
		add: (child1 := self firstChildInstance);
		add: (child2 := self secondChildInstance).

	self assert: (self decoration at: child1 name ifAbsent: [ nil ]) = child1.
	self assert: (self decoration at: child2 name ifAbsent: [ nil ]) = child2.
	self assert: (self decoration at: 'zork' ifAbsent: [ nil ]) isNil! !

!PRChildrenTest methodsFor: 'testing-accessing' stamp: 'lr 3/9/2006 11:31'!
testAtIfPresent
	| child1 child2 |
	self decoration
		add: (child1 := self firstChildInstance);
		add: (child2 := self secondChildInstance).

	self assert: (self decoration
		at: child1 name
		ifPresent: [ :val | val ]) = child1.
	self assert: (self decoration
		at: child2 name
		ifPresent: [ :val | 'zork' ]) = 'zork'.
	self assert: (self decoration
		at: 'zork'
		ifPresent: [ :val | self assert: false ]) isNil! !

!PRChildrenTest methodsFor: 'testing-accessing' stamp: 'lr 3/9/2006 11:31'!
testIncludes
	| child1 child2 |
	self decoration
		add: (child1 := self firstChildInstance);
		add: (child2 := self secondChildInstance).

	self assert: (self decoration includes: child1 name).
	self assert: (self decoration includes: child2 name).
	self deny: (self decoration includes: 'zork')! !

!PRChildrenTest methodsFor: 'testing-testing' stamp: 'lr 9/25/2006 08:20'!
testIsEmpty
	self assert: self decoration isEmpty.
	self decoration add: self firstChildInstance.
	self deny: self decoration isEmpty! !

!PRChildrenTest methodsFor: 'testing-actions' stamp: 'lr 3/9/2006 11:31'!
testRemove
	| child1 child2 |
	self decoration
		add: (child1 := self firstChildInstance);
		add: (child2 := self secondChildInstance).
	self assert: (self decoration remove: child1) = child1.
	self assert: (self decoration remove: child2) = child2.
	self assert: (self decoration isEmpty)! !

!PRChildrenTest methodsFor: 'testing-actions' stamp: 'lr 9/25/2006 08:18'!
testRemoveLast
	"Tests that the children decoration is properly removed if the last child has been removed from the decoration."

	| child |
	self decoration
		add: (child := self firstChildInstance).
	self decoration
		remove: child.
	self decorated
		decorationOfClass: self actualClass
		ifAbsent: [ ^ self ].
	self assert: false! !

!PRDecorationTest class methodsFor: 'testing' stamp: 'lr 3/30/2007 22:22'!
isAbstract
	^ true! !

!PRDecorationTest methodsFor: 'private' stamp: 'lr 3/30/2007 22:22'!
actualClass
	^ PRDecoration! !

!PRDecorationTest methodsFor: 'private' stamp: 'lr 3/9/2006 11:31'!
actualInstance
	^ self actualClass new! !

!PRDecorationTest methodsFor: 'accessing' stamp: 'lr 3/9/2006 11:31'!
decorated
	^ decorated! !

!PRDecorationTest methodsFor: 'private' stamp: 'lr 3/9/2006 11:31'!
decoratedInstance
	^ PRPage new! !

!PRDecorationTest methodsFor: 'accessing' stamp: 'lr 3/9/2006 11:31'!
decoration
	^ decoration! !

!PRDecorationTest methodsFor: 'accessing' stamp: 'lr 3/9/2006 11:31'!
instance
	^ decoration! !

!PRDecorationTest methodsFor: 'running' stamp: 'lr 3/9/2006 11:31'!
setUp
	decorated := self decoratedInstance.
	decoration := self actualInstance.
	decorated addDecoration: decoration! !

!PRDecorationTest methodsFor: 'testing-copying' stamp: 'lr 3/9/2006 11:31'!
testCopyDecorated
	| ownerCopy decorationCopy |
	ownerCopy := self decorated copy.
	decorationCopy := ownerCopy decorations first.

	self deny: self decorated == ownerCopy.
	self deny: self decorated == decorationCopy.

	self assert: self decorated decorations size = 1.
	self assert: self decorated decorations first = self decoration.
	self assert: self decorated = self decoration decorated.

	self assert: ownerCopy decorations size = 1.
	self assert: ownerCopy decorations first = decorationCopy.
	self assert: ownerCopy = decorationCopy decorated! !

!PRDecorationTest methodsFor: 'testing-copying' stamp: 'lr 3/9/2006 11:31'!
testCopyDecoration
	| decorationCopy |
	decorationCopy := self decoration copy.

	self deny: self decoration == decorationCopy.
	self assert: self decoration = decorationCopy.
	self assert: self decoration decorated = self decorated.
	self assert: decorationCopy decorated isNil! !

!PRDecorationTest methodsFor: 'testing-accessing' stamp: 'lr 3/9/2006 11:31'!
testDecorated
	self assert: self decoration decorated = self decorated! !

!PRDecorationTest methodsFor: 'testing-accessing' stamp: 'lr 3/9/2006 11:31'!
testPriority
	self assert: self decoration priority isNumber! !

!PRDecorationTest methodsFor: 'testing-utilities' stamp: 'lr 2/12/2007 19:07'!
testRemove
	self decoration remove.
	self assert: self decoration decorated isNil.
	self decorated
		decorationOfClass: self actualClass
		ifAbsent: [ ^ self ].
	self assert: false! !

PRObjectTest subclass: #PRDocumentItemTest
	instanceVariableNames: 'instance'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Pier-Tests-Document'!

PRDocumentItemTest subclass: #PRAnchorTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Pier-Tests-Document'!

!PRAnchorTest class methodsFor: 'testing' stamp: 'lr 3/30/2007 22:22'!
isAbstract
	^ false! !

!PRAnchorTest methodsFor: 'private' stamp: 'lr 3/30/2007 22:22'!
actualClass
	^ PRAnchor! !

!PRAnchorTest methodsFor: 'testing-comparing' stamp: 'lr 4/5/2007 13:16'!
testEqualName
	self deny: (self actualClass named: 'foo') = (self actualClass named: 'bar')! !

!PRAnchorTest methodsFor: 'testing-accessing' stamp: 'lr 3/9/2006 11:31'!
testName
	self instance name: 'zork'.
	self assert: self instance name = 'zork'! !

!PRAnchorTest methodsFor: 'testing-parsing' stamp: 'lr 4/5/2007 13:08'!
testParseBasic
	| wiki text tree |
	wiki := '@name'.
	text := ''.
	tree := PRDocument new
		add: (PRAnchor named: 'name');
		yourself.
	self assertWiki: wiki equalsTree: tree.
	self assertTree: tree equalsWiki: wiki.
	self assertTree: tree equalsText: text! !

!PRAnchorTest methodsFor: 'testing-parsing' stamp: 'lr 4/5/2007 13:08'!
testParseMultiple
	| wiki text tree |
	wiki := '@one
@two

@tree'.
	text := ''.
	tree := PRDocument new
		add: (PRAnchor named: 'one');
		add: (PRAnchor named: 'two');
		add: PRParagraph new;
		add: (PRAnchor named: 'tree');
		yourself.
	self assertWiki: wiki equalsTree: tree.
	self assertTree: tree equalsWiki: wiki.
	self assertTree: tree equalsText: text! !

!PRAnchorTest methodsFor: 'testing-parsing' stamp: 'lr 4/5/2007 13:08'!
testParseSpaces
	| wiki text tree |
	wiki := '@one two'.
	text := ''.
	tree := PRDocument new
		add: (PRAnchor named: 'one two');
		yourself.
	self assertWiki: wiki equalsTree: tree.
	self assertTree: tree equalsWiki: wiki.
	self assertTree: tree equalsText: text! !

!PRAnchorTest methodsFor: 'testing-instantiation' stamp: 'lr 4/5/2007 13:16'!
testWith
	instance := self actualClass named: 'test'.
	self assert: self instance name = 'test'! !

PRDocumentItemTest subclass: #PRDocumentGroupTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Pier-Tests-Document'!

!PRDocumentGroupTest class methodsFor: 'testing' stamp: 'lr 3/30/2007 22:22'!
isAbstract
	^ true! !

!PRDocumentGroupTest methodsFor: 'private' stamp: 'lr 3/30/2007 22:22'!
actualClass
	^ PRDocumentGroup! !

!PRDocumentGroupTest methodsFor: 'testing-adding' stamp: 'lr 3/9/2006 11:31'!
testAdd
	self instance add: self fooInstance.
	self assert: self instance children size = 1.
	self assert: self instance children first = self fooInstance.

	self instance add: self barInstance.
	self assert: self instance children size = 2.
	self assert: self instance children first = self fooInstance.
	self assert: self instance children second = self barInstance! !

!PRDocumentGroupTest methodsFor: 'testing-adding' stamp: 'lr 3/9/2006 11:31'!
testAddAll
	self instance addAll: self foobarInstances.
	self assert: self instance children size = 2.
	self assert: self instance children first = self fooInstance.
	self assert: self instance children second = self barInstance! !

!PRDocumentGroupTest methodsFor: 'testing-copying' stamp: 'lr 3/9/2006 11:31'!
testCopyChildren
	self instance addAll: self foobarInstances.
	self assert: self instance children = self instance copy children.
	self deny: self instance children == self instance copy children.
	self instance children
		with: self instance copy children
		do: [ :a :b | self assert: a = b. self deny: a == b ]! !

!PRDocumentGroupTest methodsFor: 'testing-testing' stamp: 'lr 3/20/2006 19:08'!
testHasChildren
	self deny: self instance hasChildren.
	self instance add: self fooInstance.
	self assert: self instance hasChildren! !

!PRDocumentGroupTest methodsFor: 'testing-accessing' stamp: 'lr 3/9/2006 11:31'!
testText
	self instance addAll: self foobarInstances.
	self assert: self instance text = 'foobar'! !

!PRDocumentGroupTest methodsFor: 'testing-instantiation' stamp: 'lr 3/9/2006 11:31'!
testWith
	instance := self actualClass with: self fooInstance.
	self assert: instance children size = 1.
	self assert: instance children first = self fooInstance! !

!PRDocumentGroupTest methodsFor: 'testing-instantiation' stamp: 'lr 3/9/2006 11:31'!
testWithAll
	instance := self actualClass withAll: self foobarInstances.
	self assert: instance children size = 2.
	self assert: instance children first = self fooInstance.
	self assert: instance children second = self barInstance! !

PRDocumentGroupTest subclass: #PRDocumentTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Pier-Tests-Document'!

!PRDocumentTest class methodsFor: 'testing' stamp: 'lr 3/30/2007 22:22'!
isAbstract
	^ false! !

!PRDocumentTest methodsFor: 'private' stamp: 'lr 3/30/2007 22:22'!
actualClass
	^ PRDocument! !

!PRDocumentTest methodsFor: 'testing-parsing' stamp: 'lr 2/12/2007 19:07'!
testParseBasic
	| wiki text tree |
	wiki := String new.
	text := String new.
	tree := PRDocument new.
	self assertWiki: wiki equalsTree: tree.
	self assertTree: tree equalsWiki: wiki.
	self assertTree: tree equalsText: text! !

PRDocumentGroupTest subclass: #PRFormatTest
	instanceVariableNames: 'otherClass'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Pier-Tests-Document'!

PRFormatTest subclass: #PRBoldFormatTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Pier-Tests-Document'!

!PRBoldFormatTest class methodsFor: 'testing' stamp: 'lr 3/30/2007 22:22'!
isAbstract
	^ false! !

!PRBoldFormatTest methodsFor: 'private' stamp: 'lr 3/30/2007 22:22'!
actualClass
	^ PRBoldFormat! !

!PRFormatTest class methodsFor: 'testing' stamp: 'lr 3/30/2007 22:22'!
isAbstract
	^ true! !

!PRFormatTest methodsFor: 'private' stamp: 'lr 3/30/2007 22:22'!
actualClass
	^ PRFormat! !

!PRFormatTest methodsFor: 'accessing' stamp: 'lr 4/5/2007 16:08'!
otherClass
	^ otherClass ifNil: [ otherClass := PRFormat allSubclasses detect: [ :each | self actualClass ~= each ] ]! !

!PRFormatTest methodsFor: 'testing-parsing' stamp: 'lr 4/5/2007 15:37'!
testParseBasic
	| wiki text tree |
	wiki := '1' , self actualClass markup , '2' , self actualClass markup , '3'.
	text := '123'.
	tree := PRDocument new
		add: (PRParagraph new
			add: (PRText content: '1');
			add: (self actualClass with: (PRText content: '2'));
			add: (PRText content: '3');
			yourself);
		yourself.
	self assertWiki: wiki equalsTree: tree.
	self assertTree: tree equalsWiki: wiki.
	self assertTree: tree equalsText: text! !

!PRFormatTest methodsFor: 'testing-parsing' stamp: 'lr 4/5/2007 14:32'!
testParseEnd
	| wiki text tree |
	wiki := '1' , self actualClass markup , '2' , self actualClass markup.
	text := '12'.
	tree := PRDocument new
		add: (PRParagraph new
			add: (PRText content: '1');
			add: (self actualClass with: (PRText content: '2'));
			yourself);
		yourself.
	self assertWiki: wiki equalsTree: tree.
	self assertTree: tree equalsWiki: wiki.
	self assertTree: tree equalsText: text! !

!PRFormatTest methodsFor: 'testing-parsing' stamp: 'lr 4/5/2007 15:57'!
testParseEscaped
	| wiki text tree |
	wiki := ' \' , self actualClass markup , '\' , self actualClass markup.
	text := ' ' , self actualClass markup , self actualClass markup.
	tree := PRDocument new
		add: (PRParagraph new
			add: (PRText content: ' ' , self actualClass markup , self actualClass markup);
			yourself);
		yourself.
	self assertWiki: wiki equalsTree: tree.
	self assertTree: tree equalsWiki: wiki.
	self assertTree: tree equalsText: text! !

!PRFormatTest methodsFor: 'testing-parsing' stamp: 'lr 4/5/2007 15:47'!
testParseIncomplete
	| wiki1 wiki2 text tree |
	wiki1 := '1' , self actualClass markup , '2'.
	wiki2 := '1\' , self actualClass markup , '2'.
	text := '1' , self actualClass markup , '2'.
	tree := PRDocument new
		add: (PRParagraph new
			add: (PRText content: '1' , self actualClass markup , '2');
			yourself);
		yourself.
	self assertWiki: wiki1 equalsTree: tree.
	self assertWiki: wiki2 equalsTree: tree.
	self assertTree: tree equalsWiki: wiki2.
	self assertTree: tree equalsText: text! !

!PRFormatTest methodsFor: 'testing-parsing' stamp: 'lr 4/5/2007 14:32'!
testParseMany
	| wiki text tree |
	wiki := '1' , self actualClass markup , '2' , self actualClass markup , '3' , self actualClass markup , '4' , self actualClass markup , '5'.
	text := '12345'.
	tree := PRDocument new
		add: (PRParagraph new
			add: (PRText content: '1');
			add: (self actualClass with: (PRText content: '2'));
			add: (PRText content: '3');
			add: (self actualClass with: (PRText content: '4'));
			add: (PRText content: '5');
			yourself);
		yourself.
	self assertWiki: wiki equalsTree: tree.
	self assertTree: tree equalsWiki: wiki.
	self assertTree: tree equalsText: text! !

!PRFormatTest methodsFor: 'testing-parsing' stamp: 'lr 4/5/2007 16:06'!
testParseNested
	| wiki text tree |
	wiki := '1' , self actualClass markup , '2' , self otherClass markup , '3' , self otherClass markup , '4' , self actualClass markup , '5'.
	text := '12345'.
	tree := PRDocument new
		add: (PRParagraph new
			add: (PRText content: '1');
			add: (self actualClass new
				add: (PRText content: '2');
				add: (self otherClass new
					add: (PRText content: '3');
					yourself);
				add: (PRText content: '4');
				yourself);
			add: (PRText content: '5');
			yourself);
		yourself.
	self assertWiki: wiki equalsTree: tree.
	self assertTree: tree equalsWiki: wiki.
	self assertTree: tree equalsText: text! !

!PRFormatTest methodsFor: 'testing-parsing' stamp: 'lr 4/5/2007 16:09'!
testParseNestedTight
	| wiki text tree |
	wiki := ' ' , self actualClass markup , self otherClass markup , self otherClass markup , self actualClass markup.
	text := ' '.
	tree := PRDocument new
		add: (PRParagraph new
			add: (PRText content: ' ');
			add: (self actualClass new
				add: self otherClass new
				yourself);
			yourself);
		yourself.
	self assertWiki: wiki equalsTree: tree.
	self assertTree: tree equalsWiki: wiki.
	self assertTree: tree equalsText: text! !

PRFormatTest subclass: #PRItalicFormatTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Pier-Tests-Document'!

!PRItalicFormatTest class methodsFor: 'testing' stamp: 'lr 3/30/2007 22:22'!
isAbstract
	^ false! !

!PRItalicFormatTest methodsFor: 'private' stamp: 'lr 3/30/2007 22:22'!
actualClass
	^ PRItalicFormat! !

PRFormatTest subclass: #PRMonospaceFormatTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Pier-Tests-Document'!

!PRMonospaceFormatTest class methodsFor: 'testing' stamp: 'lr 3/30/2007 22:22'!
isAbstract
	^ false! !

!PRMonospaceFormatTest methodsFor: 'private' stamp: 'lr 3/30/2007 22:22'!
actualClass
	^ PRMonospaceFormat! !

PRFormatTest subclass: #PRStrikethroughFormatTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Pier-Tests-Document'!

!PRStrikethroughFormatTest class methodsFor: 'testing' stamp: 'lr 3/30/2007 22:22'!
isAbstract
	^ false! !

!PRStrikethroughFormatTest methodsFor: 'private' stamp: 'lr 5/31/2007 07:48'!
actualClass
	^ PRStrikethroughFormat! !

PRFormatTest subclass: #PRSubscriptFormatTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Pier-Tests-Document'!

!PRSubscriptFormatTest class methodsFor: 'testing' stamp: 'lr 3/30/2007 22:22'!
isAbstract
	^ false! !

!PRSubscriptFormatTest methodsFor: 'private' stamp: 'lr 3/30/2007 22:22'!
actualClass
	^ PRSubscriptFormat! !

PRFormatTest subclass: #PRSuperscriptFormatTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Pier-Tests-Document'!

!PRSuperscriptFormatTest class methodsFor: 'testing' stamp: 'lr 3/30/2007 22:22'!
isAbstract
	^ false! !

!PRSuperscriptFormatTest methodsFor: 'private' stamp: 'lr 3/30/2007 22:22'!
actualClass
	^ PRSuperscriptFormat! !

PRFormatTest subclass: #PRUnderlineFormatTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Pier-Tests-Document'!

!PRUnderlineFormatTest class methodsFor: 'testing' stamp: 'lr 3/30/2007 22:22'!
isAbstract
	^ false! !

!PRUnderlineFormatTest methodsFor: 'private' stamp: 'lr 3/30/2007 22:22'!
actualClass
	^ PRUnderlineFormat! !

PRDocumentGroupTest subclass: #PRHeaderTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Pier-Tests-Document'!

!PRHeaderTest class methodsFor: 'testing' stamp: 'lr 3/30/2007 22:22'!
isAbstract
	^ false! !

!PRHeaderTest methodsFor: 'private' stamp: 'lr 3/30/2007 22:22'!
actualClass
	^ PRHeader! !

!PRHeaderTest methodsFor: 'testing-comparing' stamp: 'lr 3/9/2006 11:31'!
testEqualLevel
	self deny: (self actualClass new level: 1) = (self actualClass new level: 2)! !

!PRHeaderTest methodsFor: 'testing-accessing' stamp: 'lr 3/9/2006 11:31'!
testName
	self instance level: 3.
	self assert: self instance level = 3! !

!PRHeaderTest methodsFor: 'testing-parsing' stamp: 'lr 10/18/2007 19:22'!
testParseEmpty
	| wiki text tree |
	wiki := '!!'.
	text := ''.
	tree := PRDocument new
		add: (PRHeader new
			level: 1;
			yourself);
		yourself.
	self assertWiki: wiki equalsTree: tree.
	self assertTree: tree equalsWiki: wiki.
	self assertTree: tree equalsText: text! !

!PRHeaderTest methodsFor: 'testing-parsing' stamp: 'lr 4/5/2007 14:33'!
testParseLevel1
	| wiki text tree |
	wiki := '!!foo'.
	text := 'foo'.
	tree := PRDocument new
		add: ((PRHeader new)
			level: 1;
			add: (PRText content: 'foo');
			yourself);
		yourself.
	self assertWiki: wiki equalsTree: tree.
	self assertTree: tree equalsWiki: wiki.
	self assertTree: tree equalsText: text! !

!PRHeaderTest methodsFor: 'testing-parsing' stamp: 'lr 4/5/2007 14:33'!
testParseLevel2
	| wiki text tree |
	wiki := '!!!!foo'.
	text := 'foo'.
	tree := PRDocument new
		add: ((PRHeader new)
			level: 2;
			add: (PRText content: 'foo');
			yourself);
		yourself.
	self assertWiki: wiki equalsTree: tree.
	self assertTree: tree equalsWiki: wiki.
	self assertTree: tree equalsText: text! !

!PRHeaderTest methodsFor: 'testing-parsing' stamp: 'lr 4/5/2007 14:33'!
testParseLevel3
	| wiki text tree |
	wiki := '!!!!!!foo'.
	text := 'foo'.
	tree := PRDocument new
		add: ((PRHeader new)
			level: 3;
			add: (PRText content: 'foo');
			yourself);
		yourself.
	self assertWiki: wiki equalsTree: tree.
	self assertTree: tree equalsWiki: wiki.
	self assertTree: tree equalsText: text! !

!PRHeaderTest methodsFor: 'testing-parsing' stamp: 'lr 4/5/2007 14:33'!
testParseLevel4
	| wiki text tree |
	wiki := '!!!!!!!!foo'.
	text := 'foo'.
	tree := PRDocument new
		add: ((PRHeader new)
			level: 4;
			add: (PRText content: 'foo');
			yourself);
		yourself.
	self assertWiki: wiki equalsTree: tree.
	self assertTree: tree equalsWiki: wiki.
	self assertTree: tree equalsText: text! !

!PRHeaderTest methodsFor: 'testing-parsing' stamp: 'lr 4/5/2007 14:33'!
testParseLevel5
	| wiki text tree |
	wiki := '!!!!!!!!!!foo'.
	text := 'foo'.
	tree := PRDocument new
		add: ((PRHeader new)
			level: 5;
			add: (PRText content: 'foo');
			yourself);
		yourself.
	self assertWiki: wiki equalsTree: tree.
	self assertTree: tree equalsWiki: wiki.
	self assertTree: tree equalsText: text! !

!PRHeaderTest methodsFor: 'testing-parsing' stamp: 'lr 4/5/2007 14:33'!
testParseLevel6
	| wiki text tree |
	wiki := '!!!!!!!!!!!!foo'.
	text := 'foo'.
	tree := PRDocument new
		add: ((PRHeader new)
			level: 6;
			add: (PRText content: 'foo');
			yourself);
		yourself.
	self assertWiki: wiki equalsTree: tree.
	self assertTree: tree equalsWiki: wiki.
	self assertTree: tree equalsText: text! !

!PRHeaderTest methodsFor: 'testing-parsing' stamp: 'lr 4/5/2007 14:33'!
testParseNested
	| wiki text tree |
	wiki := '!!!!Hello *Link*'.
	text := 'Hello Link'.
	tree := PRDocument new
		add: (PRHeader new
			level: 2;
			add: (PRText content: 'Hello ');
			add: (PRInternalLink new
				reference: 'Link';
				yourself);
			yourself);
		yourself.
	self assertWiki: wiki equalsTree: tree.
	self assertTree: tree equalsWiki: wiki.
	self assertTree: tree equalsText: text! !

!PRHeaderTest methodsFor: 'testing-instantiation' stamp: 'lr 3/9/2006 11:31'!
testWithAllLevel
	instance := self actualClass withAll: self foobarInstances level: 3.
	self assert: self instance children size = 2.
	self assert: self instance children first = self fooInstance.
	self assert: self instance children second = self barInstance.
	self assert: self instance level = 3! !

PRDocumentGroupTest subclass: #PRLinkTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Pier-Tests-Document'!

PRLinkTest subclass: #PRExternalLinkTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Pier-Tests-Document'!

!PRExternalLinkTest class methodsFor: 'testing' stamp: 'lr 3/30/2007 22:22'!
isAbstract
	^ false! !

!PRExternalLinkTest methodsFor: 'private' stamp: 'lr 3/30/2007 22:22'!
actualClass
	^ PRExternalLink! !

!PRExternalLinkTest methodsFor: 'private' stamp: 'lr 3/9/2006 11:31'!
referenceString
	^ 'http://www.lukas-renggli.ch'! !

!PRExternalLinkTest methodsFor: 'testing-accessing' stamp: 'lr 10/20/2006 12:06'!
testTitle
	self instance reference: 'http://www.lukas-renggli.ch'.
	self assert: self instance title = 'http://www.lukas-renggli.ch'! !

!PRExternalLinkTest methodsFor: 'testing-accessing' stamp: 'lr 3/9/2006 11:31'!
testUrl
	self instance reference: 'http://www.lukas-renggli.ch'.
	self assert: self instance url = 'http://www.lukas-renggli.ch'! !

PRExternalLinkTest subclass: #PRGoogleLinkTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Pier-Tests-Document'!

!PRGoogleLinkTest class methodsFor: 'testing' stamp: 'lr 3/30/2007 22:22'!
isAbstract
	^ false! !

!PRGoogleLinkTest methodsFor: 'private' stamp: 'lr 3/30/2007 22:22'!
actualClass
	^ PRGoogleLink! !

!PRGoogleLinkTest methodsFor: 'private' stamp: 'lr 2/7/2007 15:12'!
referenceString
	^ 'google:foo bar'! !

!PRGoogleLinkTest methodsFor: 'testing-accessing' stamp: 'lr 2/7/2007 15:15'!
testTitle
	self instance reference: 'google:foo'.
	self assert: self instance title = 'Google (foo)'! !

!PRGoogleLinkTest methodsFor: 'testing-accessing' stamp: 'lr 2/7/2007 15:13'!
testUrl
	self instance reference: 'google:foo'.
	self assert: self instance url = 'http://www.google.com/search?q=foo'! !

PRExternalLinkTest subclass: #PRIsbnLinkTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Pier-Tests-Document'!

!PRIsbnLinkTest class methodsFor: 'testing' stamp: 'lr 3/30/2007 22:22'!
isAbstract
	^ false! !

!PRIsbnLinkTest methodsFor: 'private' stamp: 'lr 3/30/2007 22:22'!
actualClass
	^ PRIsbnLink! !

!PRIsbnLinkTest methodsFor: 'private' stamp: 'lr 3/9/2006 11:31'!
referenceString
	^ 'isbn:1590594916'! !

!PRIsbnLinkTest methodsFor: 'testing-accessing' stamp: 'lr 10/20/2006 12:17'!
testTitle
	self instance reference: 'isbn:1590594916'.
	self assert: self instance title = 'ISBN 1590594916'! !

!PRIsbnLinkTest methodsFor: 'testing-accessing' stamp: 'lr 3/9/2006 11:31'!
testUrl
	self instance reference: 'isbn:1590594916'.
	self assert: self instance url = 'http://www.amazon.com/exec/obidos/ISBN=1590594916'! !

PRExternalLinkTest subclass: #PRMailLinkTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Pier-Tests-Document'!

!PRMailLinkTest class methodsFor: 'testing' stamp: 'lr 3/30/2007 22:22'!
isAbstract
	^ false! !

!PRMailLinkTest methodsFor: 'private' stamp: 'lr 3/30/2007 22:22'!
actualClass
	^ PRMailLink! !

!PRMailLinkTest methodsFor: 'private' stamp: 'lr 3/9/2006 11:31'!
referenceString
	^ 'renggli@iam.unibe.ch'! !

!PRMailLinkTest methodsFor: 'testing-accessing' stamp: 'lr 10/20/2006 11:45'!
testTitle
	super testTitle.
	self instance reference: 'renggli@iam.unibe.ch'.
	self assert: self instance title = 'renggli@iam.unibe.ch'! !

!PRMailLinkTest methodsFor: 'testing-accessing' stamp: 'lr 5/24/2006 11:14'!
testUrl
	self instance reference: 'renggli@iam.unibe.ch'.
	self assert: (self instance url beginsWith: 'mailto:').
	self assert: self instance url ~= 'mailto:renggli@iam.unibe.ch'! !

PRExternalLinkTest subclass: #PRRfcLinkTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Pier-Tests-Document'!

!PRRfcLinkTest class methodsFor: 'testing' stamp: 'lr 3/30/2007 22:22'!
isAbstract
	^ false! !

!PRRfcLinkTest methodsFor: 'private' stamp: 'lr 3/30/2007 22:22'!
actualClass
	^ PRRfcLink! !

!PRRfcLinkTest methodsFor: 'private' stamp: 'lr 3/9/2006 11:31'!
referenceString
	^ 'rfc:1896'! !

!PRRfcLinkTest methodsFor: 'testing-accessing' stamp: 'lr 10/20/2006 12:17'!
testTitle
	self instance reference: 'rfc:1896'.
	self assert: self instance title = 'RFC 1896'! !

!PRRfcLinkTest methodsFor: 'testing-accessing' stamp: 'lr 3/9/2006 11:31'!
testUrl
	self instance reference: 'rfc:1896'.
	self assert: self instance url = 'http://www.faqs.org/rfcs/rfc1896.html'! !

PRLinkTest subclass: #PRInternalLinkTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Pier-Tests-Document'!

!PRInternalLinkTest class methodsFor: 'testing' stamp: 'lr 3/30/2007 22:22'!
isAbstract
	^ false! !

!PRInternalLinkTest methodsFor: 'private' stamp: 'lr 3/30/2007 22:22'!
actualClass
	^ PRInternalLink! !

!PRInternalLinkTest methodsFor: 'private' stamp: 'lr 3/9/2006 11:31'!
referenceString
	^ 'Page'! !

!PRInternalLinkTest methodsFor: 'testing-accessing' stamp: 'lr 3/9/2006 11:31'!
testAnchor
	self instance anchor: 'zork'.
	self assert: self instance anchor = 'zork'.
	self assert: self instance hasAnchor! !

!PRInternalLinkTest methodsFor: 'testing-comparing' stamp: 'lr 3/9/2006 11:31'!
testEqualAnchor
	self deny: (self actualClass new anchor: 'foo'; yourself) = ((self actualClass new) anchor: 'bar'; yourself)! !

!PRInternalLinkTest methodsFor: 'testing-parsing' stamp: 'lr 2/7/2007 15:18'!
testParseAnchoredEmbedded
	| wiki text tree |
	wiki := '+' , self referenceString , '@Anchor+'.
	text := self actualClass new
		reference: self referenceString;
		anchor: 'Anchor';
		embedded: true;
		title.
	tree := PRDocument new
		add: (PRParagraph new
			add: (self actualClass new
				reference: self referenceString;
				anchor: 'Anchor';
				embedded: true;
				yourself);
			yourself);
		yourself.
	self assertWiki: wiki equalsTree: tree.
	self assertTree: tree equalsWiki: wiki.
	self assertTree: tree equalsText: text! !

!PRInternalLinkTest methodsFor: 'testing-parsing' stamp: 'lr 2/7/2007 15:17'!
testParseAnchoredReferenced
	| wiki text tree |
	wiki := '*' , self referenceString , '@Anchor*'.
	text := self actualClass new
		reference: self referenceString;
		anchor: 'Anchor';
		title.
	tree := PRDocument new
		add: (PRParagraph new
			add: (self actualClass new
				reference: self referenceString;
				anchor: 'Anchor';
				yourself);
			yourself);
		yourself.
	self assertWiki: wiki equalsTree: tree.
	self assertTree: tree equalsWiki: wiki.
	self assertTree: tree equalsText: text! !

!PRInternalLinkTest methodsFor: 'testing-parsing' stamp: 'lr 4/5/2007 14:33'!
testParseEverything
	| wiki text tree |
	wiki := '*Alias>' , self referenceString , '@Anchor*'.
	text := 'Alias'.
	tree := PRDocument new
		add: (PRParagraph new
			add: (self actualClass new
				add: (PRText content: 'Alias');
				reference: self referenceString;
				anchor: 'Anchor';
				yourself);
			yourself);
		yourself.
	self assertWiki: wiki equalsTree: tree.
	self assertTree: tree equalsWiki: wiki.
	self assertTree: tree equalsText: text! !

!PRInternalLinkTest methodsFor: 'testing-accessing' stamp: 'lr 10/20/2006 11:45'!
testTitle
	super testTitle.
	self instance reference: 'page'.
	self assert: self instance title = 'page'! !

!PRLinkTest class methodsFor: 'testing' stamp: 'lr 3/30/2007 22:22'!
isAbstract
	^ true! !

!PRLinkTest methodsFor: 'private' stamp: 'lr 3/30/2007 22:22'!
actualClass
	^ PRLink! !

!PRLinkTest methodsFor: 'private' stamp: 'lr 3/9/2006 11:31'!
referenceString
	self subclassResponsibility! !

!PRLinkTest methodsFor: 'testing-accessing' stamp: 'lr 3/9/2006 11:31'!
testAlias
	self deny: self instance hasAlias.

	self instance add: self fooInstance.
	self assert: self instance hasAlias.
	self assert: self instance alias = 'foo'.

	self instance add: self barInstance.
	self assert: self instance hasAlias.
	self assert: self instance alias = 'foobar'! !

!PRLinkTest methodsFor: 'testing-accessing' stamp: 'lr 3/9/2006 11:31'!
testAnchor
	self deny: self instance hasAnchor! !

!PRLinkTest methodsFor: 'testing-accessing' stamp: 'lr 3/9/2006 11:31'!
testEmbedded
	self instance embedded: true.
	self assert: self instance isEmbedded.

	self instance embedded: false.
	self deny: self instance isEmbedded! !

!PRLinkTest methodsFor: 'testing-comparing' stamp: 'lr 3/9/2006 11:31'!
testEqualEmbedded
	self deny: (self actualClass new embedded: false; yourself) = (self actualClass new embedded: true; yourself)! !

!PRLinkTest methodsFor: 'testing-comparing' stamp: 'lr 3/9/2006 11:31'!
testEqualReference
	self deny: (self actualClass new reference: 'foo'; yourself) = (self actualClass new reference: 'bar'; yourself)! !

!PRLinkTest methodsFor: 'testing-accessing' stamp: 'lr 8/27/2007 10:22'!
testParameters
	self assert: self instance parameters isEmpty.
	self instance parameters: (Array with: 'foo' -> 'bar').
	self assert: self instance parameters size = 1! !

!PRLinkTest methodsFor: 'testing-parsing' stamp: 'lr 4/5/2007 14:33'!
testParseAliased
	| wiki text tree |
	wiki := '*Alias>' , self referenceString , '*'.
	text := 'Alias'.
	tree := PRDocument new
		add: (PRParagraph new
			add: (self actualClass new
				add: (PRText content: 'Alias');
				reference: self referenceString;
				yourself);
			yourself);
		yourself.
	self assertWiki: wiki equalsTree: tree.
	self assertTree: tree equalsWiki: wiki.
	self assertTree: tree equalsText: text! !

!PRLinkTest methodsFor: 'testing-parsing' stamp: 'lr 2/7/2007 15:06'!
testParseBasic
	| wiki text tree |
	wiki := '*' , self referenceString , '*'.
	text := self actualClass new
		reference: self referenceString;
		title.
	tree := PRDocument new
		add: (PRParagraph new
			add: (self actualClass new
				reference: self referenceString;
				yourself);
			yourself);
		yourself.
	self assertWiki: wiki equalsTree: tree.
	self assertTree: tree equalsWiki: wiki.
	self assertTree: tree equalsText: text! !

!PRLinkTest methodsFor: 'testing-parsing' stamp: 'lr 4/5/2007 14:33'!
testParseEasynessEmbedded
	| wiki1 wiki2 text tree |
	wiki1 := '+
+' , self referenceString.
	wiki2 := '\+
\+' , self referenceString.
	text := '+
+' , self referenceString.
	tree := PRDocument new
		add: (PRParagraph new
			add: (PRText content: '+');
			yourself);
		add: (PRParagraph new
			add: (PRText content: '+' , self referenceString);
			yourself);
		yourself.
	self assertWiki: wiki1 equalsTree: tree.
	self assertWiki: wiki2 equalsTree: tree.
	self assertTree: tree equalsWiki: wiki2.
	self assertTree: tree equalsText: text! !

!PRLinkTest methodsFor: 'testing-parsing' stamp: 'lr 4/5/2007 14:33'!
testParseEasynessReferenced
	| wiki1 wiki2 text tree |
	wiki1 := '*
*' , self referenceString.
	wiki2 := '\*
\*' , self referenceString.
	text := '*
*' , self referenceString.
	tree := PRDocument new
		add: (PRParagraph new
			add: (PRText content: '*');
			yourself);
		add: (PRParagraph new
			add: (PRText content: '*' , self referenceString);
			yourself);
		yourself.
	self assertWiki: wiki1 equalsTree: tree.
	self assertWiki: wiki2 equalsTree: tree.
	self assertTree: tree equalsWiki: wiki2.
	self assertTree: tree equalsText: text! !

!PRLinkTest methodsFor: 'testing-parsing' stamp: 'lr 4/5/2007 14:33'!
testParseEmbeddedAliased
	| wiki text tree |
	wiki := '+Alias>' , self referenceString , '+'.
	text := 'Alias'.
	tree := PRDocument new
		add: (PRParagraph new
			add: (self actualClass new
				add: (PRText content: 'Alias');
				reference: self referenceString;
				embedded: true;
				yourself);
			yourself);
		yourself.
	self assertWiki: wiki equalsTree: tree.
	self assertTree: tree equalsWiki: wiki.
	self assertTree: tree equalsText: text! !

!PRLinkTest methodsFor: 'testing-parsing' stamp: 'lr 2/7/2007 15:10'!
testParseEmbeddedBasic
	| wiki text tree |
	wiki := '+' , self referenceString , '+'.
	text := self actualClass new
		reference: self referenceString;
		embedded: true;
		title.
	tree := PRDocument new
		add: (PRParagraph new
			add: (self actualClass new
				reference: self referenceString;
				embedded: true;
				yourself);
			yourself);
		yourself.
	self assertWiki: wiki equalsTree: tree.
	self assertTree: tree equalsWiki: wiki.
	self assertTree: tree equalsText: text! !

!PRLinkTest methodsFor: 'testing-parsing' stamp: 'lr 4/5/2007 14:33'!
testParseEscaped
	| wiki text tree |
	wiki := 'Star \*' , self referenceString , '\*
Cross \+' , self referenceString , '\+'.
	text := 'Star *' , self referenceString , '*
Cross +' , self referenceString , '+'.
	tree := PRDocument new
		add: (PRParagraph new
			add: (PRText content: 'Star *' , self referenceString , '*');
			yourself);
		add: (PRParagraph new
			add: (PRText content: 'Cross +' , self referenceString , '+');
			yourself);
		yourself.
	self assertWiki: wiki equalsTree: tree.
	self assertTree: tree equalsWiki: wiki.
	self assertTree: tree equalsText: text! !

!PRLinkTest methodsFor: 'testing-parsing' stamp: 'lr 9/12/2007 18:18'!
testParseParameters
	| wiki text tree |
	wiki := '*Alias>' , self referenceString , '|a=1|b=2|c*'.
	text := 'Alias'.
	tree := PRDocument new
		add: (PRParagraph new
			add: (self actualClass new
				add: (PRText content: 'Alias');
				reference: self referenceString;
				parameters: (Array
					with: 'a' -> '1'
					with: 'b' -> '2'
					with: 'c' -> nil);
				yourself);
			yourself);
		yourself.
	self assertWiki: wiki equalsTree: tree.
	self assertTree: tree equalsWiki: wiki.
	self assertTree: tree equalsText: text! !

!PRLinkTest methodsFor: 'testing-parsing' stamp: 'lr 9/12/2007 18:18'!
testParseParametersEmpty
	| wiki text tree |
	wiki := '*Alias>' , self referenceString , '|a||b|*'.
	text := 'Alias'.
	tree := PRDocument new
		add: (PRParagraph new
			add: (self actualClass new
				add: (PRText content: 'Alias');
				reference: self referenceString;
				parameters: (Array
					with: 'a' -> nil
					with: 'b' -> nil);
				yourself);
			yourself);
		yourself.
	self assertWiki: wiki equalsTree: tree.
	self assertTree: tree equalsText: text! !

!PRLinkTest methodsFor: 'testing-accessing' stamp: 'lr 3/9/2006 11:31'!
testReference
	self instance reference: 'zork'.
	self assert: self instance reference = 'zork'! !

!PRLinkTest methodsFor: 'testing-accessing' stamp: 'lr 10/20/2006 11:43'!
testTitle
	self deny: self instance title notNil! !

PRDocumentGroupTest subclass: #PRListItemTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Pier-Tests-Document'!

!PRListItemTest class methodsFor: 'testing' stamp: 'lr 3/30/2007 22:22'!
isAbstract
	^ false! !

!PRListItemTest methodsFor: 'private' stamp: 'lr 3/30/2007 22:22'!
actualClass
	^ PRListItem! !

PRDocumentGroupTest subclass: #PRListTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Pier-Tests-Document'!

!PRListTest class methodsFor: 'testing' stamp: 'lr 3/30/2007 22:22'!
isAbstract
	^ true! !

!PRListTest methodsFor: 'private' stamp: 'lr 3/30/2007 22:22'!
actualClass
	^ PRList! !

!PRListTest methodsFor: 'private' stamp: 'lr 4/5/2007 14:33'!
listItemWithText: aString
	^ PRListItem new
		add: (PRText content: aString);
		yourself! !

!PRListTest methodsFor: 'testing-parsing' stamp: 'lr 10/18/2007 19:24'!
testParseEmpty
	| wiki text tree |
	wiki := self wikiString.
	text := self textString.
	tree := PRDocument new
		add: (self actualClass new
			add: PRListItem new;
			yourself);
		yourself.
	self assertWiki: wiki equalsTree: tree.
	self assertTree: tree equalsWiki: wiki.
	self assertTree: tree equalsText: text! !

!PRListTest methodsFor: 'testing-parsing' stamp: 'lr 2/7/2007 16:22'!
testParseFlat
	| wiki text tree |
	wiki := self wikiString , '1st
' , self wikiString , '2nd
' , self wikiString , '3rd'.
	text := self textString , '1st
' , self textString , '2nd
' , self textString , '3rd'.
	tree := PRDocument new
		add: (self actualClass new
			add: (self listItemWithText: '1st');
			add: (self listItemWithText: '2nd');
			add: (self listItemWithText: '3rd');
			yourself);
		yourself.
	self assertWiki: wiki equalsTree: tree.
	self assertTree: tree equalsWiki: wiki.
	self assertTree: tree equalsText: text! !

!PRListTest methodsFor: 'testing-parsing' stamp: 'lr 2/7/2007 14:51'!
testParseMixed
	| wiki tree |
	wiki := '#1
#2
-3'.
	tree := (PRDocument new)
				add: ((PROrderedList new)
							add: (self listItemWithText: '1');
							add: (self listItemWithText: '2');
							yourself);
				add: ((PRUnorderedList new)
							add: (self listItemWithText: '3');
							yourself);
				yourself.
	self assertWiki: wiki equalsTree: tree.
	self assertTree: tree equalsWiki: wiki! !

!PRListTest methodsFor: 'testing-parsing' stamp: 'lr 2/7/2007 16:25'!
testParseMultiple
	| wiki text tree |
	wiki := self wikiString , '1st
' , self wikiString , '2nd

' , self wikiString , '3rd'.
	text := self textString , '1st
' , self textString , '2nd

' , self textString , '3rd'.
	tree := PRDocument new
		add: (self actualClass new
			add: (self listItemWithText: '1st');
			add: (self listItemWithText: '2nd');
			yourself);
		add: PRParagraph new;
		add: (self actualClass new
			add: (self listItemWithText: '3rd');
			yourself);
		yourself.
	self assertWiki: wiki equalsTree: tree.
	self assertTree: tree equalsWiki: wiki.
	self assertTree: tree equalsText: text! !

!PRListTest methodsFor: 'testing-parsing' stamp: 'lr 4/5/2007 14:33'!
testParseNested1
	| wiki text tree |
	wiki := self wikiString , '1
' , self wikiString , self wikiString , '1.1
' , self wikiString , self wikiString , '1.2'.
	text := self textString , '1
' , self textString , self textString , '1.1
' , self textString , self textString , '1.2'.
	tree := PRDocument new
		add: (self actualClass new
			add: (PRListItem new
				add: (PRText content: '1');
				add: (self actualClass new
					add: (self listItemWithText: '1.1');
					add: (self listItemWithText: '1.2');
					yourself);
				yourself);
			yourself);
		yourself.
	self assertWiki: wiki equalsTree: tree.
	self assertTree: tree equalsWiki: wiki.
	self assertTree: tree equalsText: text! !

!PRListTest methodsFor: 'testing-parsing' stamp: 'lr 4/5/2007 14:33'!
testParseNested2
	| wiki text tree |
	wiki := self wikiString , '1
' , self wikiString , self wikiString , '1.1
' , self wikiString , self wikiString , self wikiString , '1.1.1'.
	text := self textString , '1
' , self textString , self textString , '1.1
' , self textString , self textString , self textString , '1.1.1'.
	tree := PRDocument new
		add: (self actualClass new
			add: (PRListItem new
				add: (PRText content: '1');
				add: (self actualClass new
					add: (PRListItem new
						add: (PRText content: '1.1');
						add: (self actualClass new
							add: (self listItemWithText: '1.1.1');
							yourself);
						yourself);
					yourself);
				yourself);
			yourself);
		yourself.
	self assertWiki: wiki equalsTree: tree.
	self assertTree: tree equalsWiki: wiki.
	self assertTree: tree equalsText: text! !

!PRListTest methodsFor: 'private' stamp: 'lr 2/7/2007 16:22'!
textString
	self subclassResponsibility! !

!PRListTest methodsFor: 'private' stamp: 'lr 2/7/2007 16:22'!
wikiString
	self subclassResponsibility! !

PRListTest subclass: #PROrderedListTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Pier-Tests-Document'!

!PROrderedListTest class methodsFor: 'testing' stamp: 'lr 3/30/2007 22:22'!
isAbstract
	^ false! !

!PROrderedListTest methodsFor: 'private' stamp: 'lr 3/30/2007 22:22'!
actualClass
	^ PROrderedList! !

!PROrderedListTest methodsFor: 'private' stamp: 'lr 2/7/2007 16:23'!
textString
	^ '* '! !

!PROrderedListTest methodsFor: 'private' stamp: 'lr 2/7/2007 16:22'!
wikiString
	^ '#'! !

PRListTest subclass: #PRUnorderedListTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Pier-Tests-Document'!

!PRUnorderedListTest class methodsFor: 'testing' stamp: 'lr 3/30/2007 22:22'!
isAbstract
	^ false! !

!PRUnorderedListTest methodsFor: 'private' stamp: 'lr 3/30/2007 22:22'!
actualClass
	^ PRUnorderedList! !

!PRUnorderedListTest methodsFor: 'private' stamp: 'lr 2/7/2007 16:23'!
textString
	^ '- '! !

!PRUnorderedListTest methodsFor: 'private' stamp: 'lr 2/7/2007 16:23'!
wikiString
	^ '-'! !

PRDocumentGroupTest subclass: #PRParagraphTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Pier-Tests-Document'!

!PRParagraphTest class methodsFor: 'testing' stamp: 'lr 3/30/2007 22:22'!
isAbstract
	^ false! !

!PRParagraphTest methodsFor: 'private' stamp: 'lr 3/30/2007 22:22'!
actualClass
	^ PRParagraph! !

!PRParagraphTest methodsFor: 'testing-parsing' stamp: 'lr 4/5/2007 14:34'!
testParseBasic
	| wiki text tree |
	wiki := 'Lorem ipsum dolor sit amet, consectetuer adipiscing elit. Nulla quis urna. Vestibulum turpis. Duis non mauris non sapien consectetuer vulputate. Duis quis pede. Nullam libero. Mauris ut turpis.'.
	text := wiki.
	tree := PRDocument new
		add: (PRParagraph new
			add: (PRText content: wiki);
			yourself);
		yourself.
	self assertWiki: wiki equalsTree: tree.
	self assertTree: tree equalsWiki: wiki.
	self assertTree: tree equalsText: text! !

!PRParagraphTest methodsFor: 'testing-parsing' stamp: 'lr 4/5/2007 14:34'!
testParseClose
	| wiki text tree |
	wiki := 'Lorem ipsum dolor sit amet, consectetuer adipiscing elit. Nulla quis urna. Vestibulum turpis. Duis non mauris non sapien consectetuer vulputate. Duis quis pede. Nullam libero. Mauris ut turpis.
Nulla mattis elementum nulla. Duis pretium magna et sem. Phasellus blandit. Ut non dolor at pede auctor semper. Donec semper dignissim ipsum. Nunc ultrices dui id ligula. Pellentesque neque. Aenean placerat nunc ut diam. Vivamus luctus magna vel velit. Donec ultricies orci eget erat. Nulla elementum ligula non est.'.
	text := wiki.
	tree := PRDocument new
		add: (PRParagraph new
			add: (PRText content: 'Lorem ipsum dolor sit amet, consectetuer adipiscing elit. Nulla quis urna. Vestibulum turpis. Duis non mauris non sapien consectetuer vulputate. Duis quis pede. Nullam libero. Mauris ut turpis.');
			yourself);
		add: (PRParagraph new
			add: (PRText content: 'Nulla mattis elementum nulla. Duis pretium magna et sem. Phasellus blandit. Ut non dolor at pede auctor semper. Donec semper dignissim ipsum. Nunc ultrices dui id ligula. Pellentesque neque. Aenean placerat nunc ut diam. Vivamus luctus magna vel velit. Donec ultricies orci eget erat. Nulla elementum ligula non est.');
			yourself);
		yourself.
	self assertWiki: wiki equalsTree: tree.
	self assertTree: tree equalsWiki: wiki.
	self assertTree: tree equalsText: text! !

!PRParagraphTest methodsFor: 'testing-parsing' stamp: 'lr 4/5/2007 14:34'!
testParseSpare
	| wiki text tree |
	wiki := 'Lorem ipsum dolor sit amet, consectetuer adipiscing elit. Nulla quis urna. Vestibulum turpis. Duis non mauris non sapien consectetuer vulputate. Duis quis pede. Nullam libero. Mauris ut turpis.

Nulla mattis elementum nulla. Duis pretium magna et sem. Phasellus blandit. Ut non dolor at pede auctor semper. Donec semper dignissim ipsum. Nunc ultrices dui id ligula. Pellentesque neque. Aenean placerat nunc ut diam. Vivamus luctus magna vel velit. Donec ultricies orci eget erat. Nulla elementum ligula non est.'.
	text := wiki.
	tree := PRDocument new
		add: (PRParagraph new
			add: (PRText content: 'Lorem ipsum dolor sit amet, consectetuer adipiscing elit. Nulla quis urna. Vestibulum turpis. Duis non mauris non sapien consectetuer vulputate. Duis quis pede. Nullam libero. Mauris ut turpis.');
			yourself);
		add: PRParagraph new;
		add: (PRParagraph new
			add: (PRText content: 'Nulla mattis elementum nulla. Duis pretium magna et sem. Phasellus blandit. Ut non dolor at pede auctor semper. Donec semper dignissim ipsum. Nunc ultrices dui id ligula. Pellentesque neque. Aenean placerat nunc ut diam. Vivamus luctus magna vel velit. Donec ultricies orci eget erat. Nulla elementum ligula non est.');
			yourself);
		yourself.
	self assertWiki: wiki equalsTree: tree.
	self assertTree: tree equalsWiki: wiki.
	self assertTree: tree equalsText: text! !

PRDocumentGroupTest subclass: #PRPreformattedTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Pier-Tests-Document'!

!PRPreformattedTest class methodsFor: 'testing' stamp: 'lr 3/30/2007 22:22'!
isAbstract
	^ false! !

!PRPreformattedTest methodsFor: 'private' stamp: 'lr 3/30/2007 22:22'!
actualClass
	^ PRPreformatted! !

!PRPreformattedTest methodsFor: 'testing-parsing' stamp: 'lr 4/5/2007 14:34'!
testParseBasic
	| wiki text tree |
	wiki := '=Line'.
	text := 'Line'.
	tree := PRDocument new
		add: (PRPreformatted new
			add: (PRText content: 'Line');
			yourself);
		yourself.
	self assertWiki: wiki equalsTree: tree.
	self assertTree: tree equalsWiki: wiki.
	self assertTree: tree equalsText: text! !

!PRPreformattedTest methodsFor: 'testing-parsing' stamp: 'lr 10/18/2007 19:43'!
testParseEmpty
	| wiki text tree |
	wiki := '='.
	text := ''.
	tree := PRDocument new
		add: (PRPreformatted new
			add: (PRText content: '');
			yourself);
		yourself.
	self assertWiki: wiki equalsTree: tree.
	self assertTree: tree equalsWiki: wiki.
	self assertTree: tree equalsText: text! !

!PRPreformattedTest methodsFor: 'testing-parsing' stamp: 'lr 4/5/2007 14:34'!
testParseMultiple
	| wiki text tree |
	wiki := '=line 1.1
=line 1.2

=line 2.1'.
	text := 'line 1.1
line 1.2

line 2.1'.
	tree := PRDocument new
		add: (PRPreformatted new
			add: (PRText content: 'line 1.1');
			add: (PRText content: 'line 1.2');
			yourself);
		add: PRParagraph new;
		add: (PRPreformatted new
			add: (PRText content: 'line 2.1');
			yourself);
		yourself.
	self assertWiki: wiki equalsTree: tree.
	self assertTree: tree equalsWiki: wiki.
	self assertTree: tree equalsText: text! !

!PRPreformattedTest methodsFor: 'testing-parsing' stamp: 'lr 4/5/2007 14:34'!
testParseSpaces
	| wiki text tree |
	wiki := '=   A line with 3 spaces
=	A line with a tab'.
	text := '   A line with 3 spaces
	A line with a tab'.
	tree := PRDocument new
		add: (PRPreformatted new
			add: (PRText content: '   A line with 3 spaces');
			add: (PRText content: '	A line with a tab');
			yourself);
		yourself.
	self assertWiki: wiki equalsTree: tree.
	self assertTree: tree equalsWiki: wiki.
	self assertTree: tree equalsText: text! !

!PRPreformattedTest methodsFor: 'testing-parsing' stamp: 'lr 4/5/2007 14:34'!
testParseSpecials
	| wiki text tree |
	wiki := '=|, {, }, *, *, [, ||, |{, |}, +, +'.
	text := '|, {, }, *, *, [, ||, |{, |}, +, +'.
	tree := PRDocument new
		add: (PRPreformatted new
			add: (PRText content: '|, {, }, *, *, [, ||, |{, |}, +, +');
			yourself);
		yourself.
	self assertWiki: wiki equalsTree: tree.
	self assertTree: tree equalsWiki: wiki.
	self assertTree: tree equalsText: text! !

PRDocumentGroupTest subclass: #PRTableCellTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Pier-Tests-Document'!

!PRTableCellTest class methodsFor: 'testing' stamp: 'lr 3/30/2007 22:22'!
isAbstract
	^ false! !

!PRTableCellTest methodsFor: 'private' stamp: 'lr 3/30/2007 22:22'!
actualClass
	^ PRTableCell! !

!PRTableCellTest methodsFor: 'testing-accessing' stamp: 'lr 3/9/2006 11:31'!
testAlign
	self instance align: #right.
	self assert: self instance align = #right! !

!PRTableCellTest methodsFor: 'testing-accessing' stamp: 'lr 3/9/2006 11:31'!
testBeAlignedCenter
	self instance beAlignedCenter.
	self assert: self instance align = #center.
	self assert: self instance isAlignedCenter.
	self deny: self instance isAlignedLeft.
	self deny: self instance isAlignedRight! !

!PRTableCellTest methodsFor: 'testing-accessing' stamp: 'lr 3/9/2006 11:31'!
testBeAlignedLeft
	self instance beAlignedLeft.
	self assert: self instance align = #left.
	self deny: self instance isAlignedCenter.
	self assert: self instance isAlignedLeft.
	self deny: self instance isAlignedRight! !

!PRTableCellTest methodsFor: 'testing-accessing' stamp: 'lr 3/9/2006 11:31'!
testBeAlignedRight
	self instance beAlignedRight.
	self assert: self instance align = #right.
	self deny: self instance isAlignedCenter.
	self deny: self instance isAlignedLeft.
	self assert: self instance isAlignedRight! !

!PRTableCellTest methodsFor: 'testing-comparing' stamp: 'lr 3/9/2006 11:31'!
testEqualAlign
	self deny: self actualClass new beAlignedRight
				= self actualClass new beAlignedCenter.
	self deny: self actualClass new beAlignedCenter
				= self actualClass new beAlignedLeft! !

!PRTableCellTest methodsFor: 'testing-parsing' stamp: 'lr 4/5/2007 14:34'!
testParseAlign1
	| wiki text tree |
	wiki := '|{left||center|}right'.
	text := 'left	center	right'.
	tree := PRDocument new
		add: (PRTable new
			add: (PRTableRow new
				add: (PRTableCell new
					beAlignedLeft;
					add: (PRText content: 'left');
					yourself);
				add: (PRTableCell new
					beAlignedCenter;
					add: (PRText content: 'center');
					yourself);
				add: (PRTableCell new
					beAlignedRight;
					add: (PRText content: 'right');
					yourself);
				yourself);
			yourself);
		yourself.
	self assertWiki: wiki equalsTree: tree.
	self assertTree: tree equalsWiki: wiki.
	self assertTree: tree equalsText: text! !

!PRTableCellTest methodsFor: 'testing-parsing' stamp: 'lr 4/5/2007 14:34'!
testParseAlign2
	| wiki text tree |
	wiki := '|}right|none|{left|none'.
	text := 'right	none	left	none'.
	tree := PRDocument new
		add: (PRTable new
			add: (PRTableRow new
				add: (PRTableCell new
					beAlignedRight;
					add: (PRText content: 'right');
					yourself);
				add: (PRTableCell new
					add: (PRText content: 'none');
					yourself);
				add: (PRTableCell new
					beAlignedLeft;
					add: (PRText content: 'left');
					yourself);
				add: (PRTableCell new
					add: (PRText content: 'none');
					yourself);
				yourself);
			yourself);
		yourself.
	self assertWiki: wiki equalsTree: tree.
	self assertTree: tree equalsWiki: wiki.
	self assertTree: tree equalsText: text! !

!PRTableCellTest methodsFor: 'testing-parsing' stamp: 'lr 4/5/2007 14:34'!
testParseEncoding
	| wiki text tree |
	wiki := '|*link*|+embedded+|foo{}'.
	text := 'link	embedded	foo{}'.
	tree := PRDocument new
		add: (PRTable new
			add: (PRTableRow new
				add: (PRTableCell new
					add: (PRInternalLink new
						reference: 'link';
						yourself);
					yourself);
				add: (PRTableCell new
					add: (PRInternalLink new
						reference: 'embedded';
						embedded: true;
						yourself);
					yourself);
				add: (PRTableCell new
					add: (PRText content: 'foo{}');
					yourself);
				yourself);
			yourself);
		yourself.
	self assertWiki: wiki equalsTree: tree.
	self assertTree: tree equalsWiki: wiki.
	self assertTree: tree equalsText: text! !

PRDocumentGroupTest subclass: #PRTableRowTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Pier-Tests-Document'!

!PRTableRowTest class methodsFor: 'testing' stamp: 'lr 3/30/2007 22:22'!
isAbstract
	^ false! !

!PRTableRowTest methodsFor: 'private' stamp: 'lr 3/30/2007 22:22'!
actualClass
	^ PRTableRow! !

!PRTableRowTest methodsFor: 'testing-accessing' stamp: 'lr 3/9/2006 11:31'!
testCount
	self instance add: PRTableCell new.
	self assert: self instance columnCount = 1.

	self instance add: PRTableCell new.
	self assert: self instance columnCount = 2! !

PRDocumentGroupTest subclass: #PRTableTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Pier-Tests-Document'!

!PRTableTest class methodsFor: 'testing' stamp: 'lr 3/30/2007 22:22'!
isAbstract
	^ false! !

!PRTableTest methodsFor: 'private' stamp: 'lr 3/30/2007 22:22'!
actualClass
	^ PRTable! !

!PRTableTest methodsFor: 'testing-accessing' stamp: 'lr 3/21/2006 18:43'!
testCount
	self instance add: (PRTableRow new add: PRTableCell new; yourself).
	self assert: self instance rowCount = 1; assert: self instance columnCount = 1.

	self instance add: (PRTableRow new add: PRTableCell new; add: PRTableCell new; yourself).
	self assert: self instance rowCount = 2; assert: self instance columnCount = 2.

	self instance add: (PRTableRow new add: PRTableCell new; yourself).
	self assert: self instance rowCount = 3; assert: self instance columnCount = 2! !

!PRTableTest methodsFor: 'testing-parsing' stamp: 'lr 4/5/2007 14:34'!
testParseBasic
	| wiki text tree |
	wiki := '|cell'.
	text := 'cell'.
	tree := PRDocument new
		add: (PRTable new
			add: (PRTableRow new
				add: (PRTableCell new
					add: (PRText content: 'cell');
					yourself);
				yourself);
			yourself);
		yourself.
	self assertWiki: wiki equalsTree: tree.
	self assertTree: tree equalsWiki: wiki.
	self assertTree: tree equalsText: text! !

!PRTableTest methodsFor: 'testing-parsing' stamp: 'lr 4/5/2007 14:34'!
testParseSquare
	| wiki text tree |
	wiki := '|a11|a12
|a21|a22'.
	text := 'a11	a12
a21	a22'.
	tree := PRDocument new
		add: (PRTable new
			add: (PRTableRow new
				add: (PRTableCell new
					add: (PRText content: 'a11');
					yourself);
				add: (PRTableCell new
					add: (PRText content: 'a12');
					yourself);
				yourself);
			add: (PRTableRow new
				add: (PRTableCell new
					add: (PRText content: 'a21');
					yourself);
				add: (PRTableCell new
					add: (PRText content: 'a22');
					yourself);
				yourself);
			yourself);
		yourself.
	self assertWiki: wiki equalsTree: tree.
	self assertTree: tree equalsWiki: wiki.
	self assertTree: tree equalsText: text! !

!PRTableTest methodsFor: 'testing-parsing' stamp: 'lr 4/5/2007 14:34'!
testParseTriangle
	| wiki text tree |
	wiki := '|a11
|a21|a22
|a31|a32|a33'.
	text := 'a11
a21	a22
a31	a32	a33'.
	tree := PRDocument new
		add: (PRTable new
			add: (PRTableRow new
				add: (PRTableCell new
					add: (PRText content: 'a11');
					yourself);
				yourself);
			add: (PRTableRow new
				add: (PRTableCell new
					add: (PRText content: 'a21');
					yourself);
				add: (PRTableCell new
					add: (PRText content: 'a22');
					yourself);
				yourself);
			add: (PRTableRow new
				add: (PRTableCell new
					add: (PRText content: 'a31');
					yourself);
				add: (PRTableCell new
					add: (PRText content: 'a32');
					yourself);
				add: (PRTableCell new
					add: (PRText content: 'a33');
					yourself);
				yourself);
			yourself);
		yourself.
	self assertWiki: wiki equalsTree: tree.
	self assertTree: tree equalsWiki: wiki.
	self assertTree: tree equalsText: text! !

!PRDocumentItemTest class methodsFor: 'testing' stamp: 'lr 3/30/2007 22:22'!
isAbstract
	^ true! !

!PRDocumentItemTest methodsFor: 'private' stamp: 'lr 3/30/2007 22:22'!
actualClass
	^ PRDocumentItem! !

!PRDocumentItemTest methodsFor: 'private' stamp: 'lr 3/9/2006 11:31'!
actualInstance
	^ self actualClass new! !

!PRDocumentItemTest methodsFor: 'utilities' stamp: 'lr 2/7/2007 16:24'!
assertTree: aDocument equalsText: aString
	self
		assert: (PRTextWriter write: aDocument) = aString
		description: aString resumable: true! !

!PRDocumentItemTest methodsFor: 'utilities' stamp: 'lr 4/5/2007 15:49'!
assertTree: aDocument equalsWiki: aString
	"Asswert that traversing aDocument using the wiki writer results in aString."

	self
		assert: (PRWikiWriter write: aDocument) = aString
		description: aString resumable: true! !

!PRDocumentItemTest methodsFor: 'utilities' stamp: 'lr 8/27/2007 10:39'!
assertWiki: aString equalsTree: aDocument
	"Assert that parsing aString results in aDocument."

	self
		assert: (PRDocumentParser parse: aString) = aDocument
		description: aString resumable: true! !

!PRDocumentItemTest methodsFor: 'private' stamp: 'lr 4/5/2007 14:32'!
barInstance
	^ PRText content: 'bar'! !

!PRDocumentItemTest methodsFor: 'private' stamp: 'lr 4/5/2007 14:32'!
fooInstance
	^ PRText content: 'foo'! !

!PRDocumentItemTest methodsFor: 'private' stamp: 'lr 3/9/2006 11:31'!
foobarInstances
	^ Array with: self fooInstance with: self barInstance! !

!PRDocumentItemTest methodsFor: 'accessing' stamp: 'lr 3/9/2006 11:31'!
instance
	^ instance! !

!PRDocumentItemTest methodsFor: 'running' stamp: 'lr 3/9/2006 11:31'!
setUp
	super setUp.
	instance := self actualInstance! !

!PRDocumentItemTest methodsFor: 'testing-copying' stamp: 'lr 3/9/2006 11:31'!
testCopy
	self assert: self instance = self instance copy.
	self assert: self instance hash = self instance copy hash.

	self deny: self instance == self instance copy! !

!PRDocumentItemTest methodsFor: 'testing-comparing' stamp: 'lr 3/9/2006 11:31'!
testEqueal
	self assert: self instance = self instance.
	self assert: self instance = self actualInstance! !

!PRDocumentItemTest methodsFor: 'testing-comparing' stamp: 'lr 3/9/2006 11:31'!
testEquealNil
	self deny: self instance isNil! !

!PRDocumentItemTest methodsFor: 'testing-comparing' stamp: 'lr 3/9/2006 11:31'!
testEquealOther
	self deny: self instance = self fooInstance.
	self deny: self instance = self barInstance! !

!PRDocumentItemTest methodsFor: 'testing-testing' stamp: 'lr 3/9/2006 11:31'!
testHasChildren
	self deny: self instance hasChildren! !

!PRDocumentItemTest methodsFor: 'testing-testing' stamp: 'lr 3/9/2006 11:31'!
testHasOwner
	self deny: self instance hasOwner! !

!PRDocumentItemTest methodsFor: 'testing-comparing' stamp: 'lr 3/9/2006 11:31'!
testHash
	self assert: self instance hash = self instance copy hash! !

!PRDocumentItemTest methodsFor: 'testing-accessing' stamp: 'lr 3/9/2006 11:31'!
testOwner
	self assert: self instance owner isNil! !

!PRDocumentItemTest methodsFor: 'testing-accessing' stamp: 'lr 3/9/2006 11:31'!
testText
	self assert: self instance text isString! !

PRDocumentItemTest subclass: #PRHorizontalRuleTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Pier-Tests-Document'!

!PRHorizontalRuleTest class methodsFor: 'testing' stamp: 'lr 3/30/2007 22:22'!
isAbstract
	^ false! !

!PRHorizontalRuleTest methodsFor: 'private' stamp: 'lr 3/30/2007 22:22'!
actualClass
	^ PRHorizontalRule! !

!PRHorizontalRuleTest methodsFor: 'testing-parsing' stamp: 'lr 2/7/2007 16:42'!
testParseBasic
	| wiki text tree |
	wiki := '_'.
	text := self textString.
	tree := PRDocument new
		add: PRHorizontalRule new;
		yourself.
	self assertWiki: wiki equalsTree: tree.
	self assertTree: tree equalsWiki: wiki.
	self assertTree: tree equalsText: text! !

!PRHorizontalRuleTest methodsFor: 'testing-parsing' stamp: 'lr 4/5/2007 15:59'!
testParseLink
	| wiki1 wiki2 text tree |
	wiki1 := '_ *link*'.
	wiki2 := '\_ *link*'.
	text := '_ link'.
	tree := PRDocument new
		add: (PRParagraph new
			add: (PRText content: '_ ');
			add: (PRInternalLink new
				reference: 'link';
				yourself);
			yourself);
		yourself.
	self assertWiki: wiki1 equalsTree: tree.
	self assertWiki: wiki2 equalsTree: tree.
	self assertTree: tree equalsWiki: wiki2.
	self assertTree: tree equalsText: text! !

!PRHorizontalRuleTest methodsFor: 'testing-parsing' stamp: 'lr 2/7/2007 16:44'!
testParseMultiple
	| wiki text tree |
	wiki := '_
_

_'.
	text := self textString , '
' , self textString , '

' , self textString.
	tree := PRDocument new
		add: PRHorizontalRule new;
		add: PRHorizontalRule new;
		add: PRParagraph new;
		add: PRHorizontalRule new;
		yourself.
	self assertWiki: wiki equalsTree: tree.
	self assertTree: tree equalsWiki: wiki.
	self assertTree: tree equalsText: text! !

!PRHorizontalRuleTest methodsFor: 'testing-parsing' stamp: 'lr 4/5/2007 14:33'!
testParseParagraph
	| wiki text tree |
	wiki := '\_ is parsed as paragraph'.
	text := '_ is parsed as paragraph'.
	tree := PRDocument new
		add: (PRParagraph new
			add: (PRText content: '_ is parsed as paragraph');
			yourself);
		yourself.
	self assertWiki: wiki equalsTree: tree.
	self assertTree: tree equalsWiki: wiki.
	self assertTree: tree equalsText: text! !

!PRHorizontalRuleTest methodsFor: 'testing-parsing' stamp: 'nfr 9/26/2007 09:55'!
testParseSpaces
	| wiki text tree |
	wiki := '_       '.
	text := self textString.
	tree := PRDocument new
		add: PRHorizontalRule new;
		yourself.
	self assertWiki: wiki equalsTree: tree.
	self assertTree: tree equalsWiki: '_'.
	self assertTree: tree equalsText: text! !

!PRHorizontalRuleTest methodsFor: 'private' stamp: 'lr 2/7/2007 16:42'!
textString
	^ String new: 40 withAll: $-! !

PRDocumentItemTest subclass: #PRTextTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Pier-Tests-Document'!

!PRTextTest class methodsFor: 'testing' stamp: 'lr 3/30/2007 22:22'!
isAbstract
	^ false! !

!PRTextTest methodsFor: 'private' stamp: 'lr 3/30/2007 22:22'!
actualClass
	^ PRText! !

!PRTextTest methodsFor: 'testing-instantiation' stamp: 'lr 4/5/2007 14:41'!
testContent
	instance := self actualClass content: 'zork'.
	self assert: self instance text = 'zork'! !

!PRTextTest methodsFor: 'testing-comparing' stamp: 'lr 4/5/2007 14:43'!
testEqualText
	self deny: (self actualClass content: 'foo') = (self actualClass content: 'bar')! !

!PRTextTest methodsFor: 'testing-parsing' stamp: 'lr 4/5/2007 14:36'!
testEscapeFirst
	| wiki tree |
	wiki := '\* text
\+ text
\= text
\@ text
\!! text
\| text
\# text
\- text'.
	tree := (PRDocument new)
		add: (PRParagraph new
			add: (PRText content: '* text');
			yourself);
		add: (PRParagraph new
			add: (PRText content: '+ text');
			yourself);
		add: (PRParagraph new
			add: (PRText content: '= text');
			yourself);
		add: (PRParagraph new
			add: (PRText content: '@ text');
			yourself);
		add: (PRParagraph new
			add: (PRText content: '!! text');
			yourself);
		add: (PRParagraph new
			add: (PRText content: '| text');
			yourself);
		add: (PRParagraph new
			add: (PRText content: '# text');
			yourself);
		add: (PRParagraph new
			add: (PRText content: '- text');
			yourself);
		yourself.
	self assertWiki: wiki equalsTree: tree.
	self assertTree: tree equalsWiki: wiki! !

!PRTextTest methodsFor: 'testing-parsing' stamp: 'lr 4/5/2007 14:36'!
testEscapeStrange
	| wiki tree |
	wiki := '< text
> text'.
	tree := PRDocument new
		add: (PRParagraph new
			add: (PRText content: '< text');
			yourself);
		add: (PRParagraph new
			add: (PRText content: '> text');
			yourself);
		yourself.
	self assertWiki: wiki equalsTree: tree.
	self assertTree: tree equalsWiki: wiki! !

!PRTextTest methodsFor: 'testing-parsing' stamp: 'lr 4/5/2007 14:37'!
testEscapeText
	| wiki tree |
	wiki := 'Text: \*\+'.
	tree := PRDocument new
		add: (PRParagraph new
			add: (PRText content: 'Text: *+');
			yourself);
		yourself.
	self assertWiki: wiki equalsTree: tree.
	self assertTree: tree equalsWiki: wiki! !

!PRTextTest methodsFor: 'testing-parsing' stamp: 'lr 4/5/2007 14:39'!
testEscapeWiki
	| wiki tree |
	wiki := 'Wiki: =, |, !!, #, {, }, |{, ||, |}, [, ] and -'.
	tree := PRDocument new
		add: (PRParagraph new
			add: (PRText content: 'Wiki: =, |, !!, #, {, }, |{, ||, |}, [, ] and -');
			yourself);
		yourself.
	self assertWiki: wiki equalsTree: tree.
	self assertTree: tree equalsWiki: wiki! !

!PRTextTest methodsFor: 'testing-parsing' stamp: 'lr 4/5/2007 14:39'!
testParseBasic
	| wiki tree |
	wiki := 'abcdefghijklmnopqrstuvwxyz... ABCDEFGHIJKLMNOPQRSTUVWXYZ... 0123456789...'.
	tree := PRDocument new
		add: (PRParagraph new
			add: (PRText content: 'abcdefghijklmnopqrstuvwxyz... ABCDEFGHIJKLMNOPQRSTUVWXYZ... 0123456789...');
			yourself);
		yourself.
	self assertWiki: wiki equalsTree: tree.
	self assertTree: tree equalsWiki: wiki! !

!PRTextTest methodsFor: 'testing-parsing' stamp: 'lr 4/5/2007 14:40'!
testParseHtml
	| wiki tree |
	wiki := '<strong>strong <emph>strong, emph</emph></strong>'.
	tree := PRDocument new
		add: (PRParagraph new
			add: (PRText content: '<strong>strong <emph>strong, emph</emph></strong>');
			yourself);
		yourself.
	self assertWiki: wiki equalsTree: tree.
	self assertTree: tree equalsWiki: wiki! !

!PRTextTest methodsFor: 'testing-parsing' stamp: 'lr 4/5/2007 14:40'!
testParseLatex
	| wiki text tree |
	wiki := '\\begin{foo}[bar]$zork$\\end{foo}'.
	text := '\begin{foo}[bar]$zork$\end{foo}'.
	tree := PRDocument new
		add: (PRParagraph new
			add: (PRText content: '\begin{foo}[bar]$zork$\end{foo}');
			yourself);
		yourself.
	self assertWiki: wiki equalsTree: tree.
	self assertTree: tree equalsWiki: wiki.
	self assertTree: tree equalsText: text! !

!PRTextTest methodsFor: 'testing-parsing' stamp: 'lr 4/5/2007 14:40'!
testParseSpecial
	| wiki tree |
	wiki := '????????????????????????????????Ƭج????????ĦŦǦɦѦ֦ܦ????ߦƦ???'.
	tree := (PRDocument new)
				add: ((PRParagraph new)
							add: (PRText
										content: '????????????????????????????????Ƭج????????ĦŦǦɦѦ֦ܦ????ߦƦ???');
							yourself);
				yourself.
	self assertWiki: wiki equalsTree: tree.
	self assertTree: tree equalsWiki: wiki! !

!PRTextTest methodsFor: 'testing-parsing' stamp: 'lr 4/5/2007 14:40'!
testParseWiki
	| wiki tree |
	wiki := ' !!_#-|=]@:<>\*'.
	tree := (PRDocument new)
				add: ((PRParagraph new)
							add: (PRText content: ' !!_#-|=]@:<>*');
							yourself);
				yourself.
	self assertWiki: wiki equalsTree: tree.
	self assertTree: tree equalsWiki: wiki! !

!PRTextTest methodsFor: 'testing-accessing' stamp: 'lr 3/9/2006 11:31'!
testText
	self instance text: 'zork'.
	self assert: self instance text = 'zork'! !

PRObjectTest subclass: #PRKernelTest
	instanceVariableNames: 'kernel'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Pier-Tests-Kernel'!

!PRKernelTest class methodsFor: 'testing' stamp: 'lr 3/30/2007 22:22'!
isAbstract
	^ false! !

!PRKernelTest methodsFor: 'private' stamp: 'lr 3/30/2007 22:22'!
actualClass
	^ PRKernel! !

!PRKernelTest methodsFor: 'accessing' stamp: 'lr 3/9/2006 11:31'!
instance
	^ self kernel! !

!PRKernelTest methodsFor: 'accessing' stamp: 'lr 3/9/2006 11:31'!
kernel
	^ kernel ifNil: [ kernel := self kernelInstance ]! !

!PRKernelTest methodsFor: 'testing' stamp: 'lr 1/17/2007 10:44'!
testInitialState
	self deny: self kernel name isNil.
	self deny: self kernel root isNil.
	self deny: self kernel persistency isNil! !

!PRKernelTest methodsFor: 'testing-accessing' stamp: 'lr 3/9/2006 11:31'!
testName
	self kernel name: 'kernel'.
	self assert: self kernel name = 'kernel'! !

!PRKernelTest methodsFor: 'testing-accessing' stamp: 'lr 3/5/2007 14:03'!
testPersistency
	| persistency |
	self kernel persistency: (persistency := PRImagePersistency new).
	self assert: self kernel persistency = persistency.
	self assert: self kernel = persistency kernel.

	self should: [ self kernel persistency: nil ] raise: PRPersistencyError.
	self assert: self kernel persistency = persistency.
	self assert: self kernel = persistency kernel.

	self kernel persistency: PRNullPersistency new.
	self deny: self kernel = persistency kernel.
	self deny: persistency kernel notNil! !

!PRKernelTest methodsFor: 'testing-accessing' stamp: 'lr 3/9/2006 11:31'!
testRoot
	| structure |
	self kernel root: (structure := PRPage new).
	self assert: self kernel root = structure! !

!PRObjectTest class methodsFor: 'building' stamp: 'lr 3/9/2006 11:31'!
buildTestClassFor: aClass
	" self buildTestClassFor: PRObject "

	| thisName thisClass thisCategory parentClass |
	thisName := (aClass name , 'Test') asSymbol.
	(thisName beginsWith: 'PR')
		ifFalse: [ ^ self ].
	thisClass := MACompatibility classNamed: thisName.
	thisCategory := 'Pier-Tests-' , (aClass category copyAfterLast: $-).
	parentClass := self = thisClass
		ifTrue: [ self superclass ]
		ifFalse: [ Smalltalk classNamed: (aClass superclass name , 'Test') asSymbol ].
	thisClass := parentClass
		subclass: thisName
		instanceVariableNames: (thisClass isNil
			ifFalse: [ thisClass instanceVariablesString ]
			ifTrue: [ String new ])
			classVariableNames: ''
			poolDictionaries: ''
			category: thisCategory.
	thisClass
		compile: 'actualClass
	^ ' , aClass name
		classified: #private.
	thisClass class
		compile: 'isAbstract
	^ ' , aClass isAbstract asString
		classified: #testing.
	aClass subclassesDo: [ :each | self buildTestClassFor: each ]! !

!PRObjectTest class methodsFor: 'testing' stamp: 'lr 3/30/2007 22:22'!
isAbstract
	^ true! !

!PRObjectTest class methodsFor: 'testing' stamp: 'lr 3/9/2006 11:31'!
shouldInheritSelectors
	^ true! !

!PRObjectTest methodsFor: 'private' stamp: 'lr 3/30/2007 22:22'!
actualClass
	^ PRObject! !

!PRObjectTest methodsFor: 'private' stamp: 'lr 3/9/2006 11:31'!
contextInstance
	^ PRContext kernel: self kernelInstance! !

!PRObjectTest methodsFor: 'accessing' stamp: 'lr 3/9/2006 11:31'!
instance
	self subclassResponsibility! !

!PRObjectTest methodsFor: 'private' stamp: 'lr 3/9/2006 11:31'!
kernelInstance
	^ PRKernel new
		name: 'test';
		root: self rootInstance;
		persistency: self persistencyInstance;
		yourself! !

!PRObjectTest methodsFor: 'private' stamp: 'lr 3/9/2006 11:31'!
persistencyInstance
	^ PRNullPersistency new! !

!PRObjectTest methodsFor: 'private' stamp: 'lr 1/15/2007 21:34'!
rootInstance
	^ (PRPage named: 'root')
		addChild: ((PRPage named: 'folder')
			addChild: (PRPage named: 'child');
			addChild: (self structureInstance);
			yourself);
		yourself! !

!PRObjectTest methodsFor: 'private' stamp: 'lr 1/15/2007 21:34'!
structureInstance
	^ PRPage named: 'structure'! !

!PRObjectTest methodsFor: 'testing-copying' stamp: ' 24/9/07 14:04'!
testCopyProperties
	self assert: self instance properties =@ self instance copy properties.
	self deny: self instance properties == self instance copy properties! !

!PRObjectTest methodsFor: 'testing-properties' stamp: 'lr 3/9/2006 11:31'!
testProperties
	self assert: self instance properties notNil.
	self instance instVarNamed: 'properties' put: nil.

	self instance propertyAt: #foo put: #bar.
	self instance instVarNamed: 'properties' put: nil.

	self instance propertyAt: #foo ifAbsent: [ nil ].
	self instance instVarNamed: 'properties' put: nil.

	self instance propertyAt: #foo ifAbsentPut: [ #bar ].
	self instance instVarNamed: 'properties' put: nil.

	self instance hasProperty: #foo.
	self instance instVarNamed: 'properties' put: nil! !

!PRObjectTest methodsFor: 'testing-properties' stamp: 'lr 3/5/2007 14:07'!
testPropertiesAt
	self assert: (self instance propertyAt: #foo put: 'bar') = 'bar'.
	self assert: (self instance propertyAt: #foo) = 'bar'.
	self should: [ self instance propertyAt: #bar ] raise: MAPropertyError! !

!PRObjectTest methodsFor: 'testing-properties' stamp: 'lr 3/9/2006 11:31'!
testPropertiesAtIfAbsent
	self assert: (self instance propertyAt: #foo put: 'bar') = 'bar'.
	self assert: (self instance propertyAt: #foo ifAbsent: [ 'baz' ]) = 'bar'.
	self assert: (self instance propertyAt: #bar ifAbsent: [ 'baz' ]) = 'baz'! !

!PRObjectTest methodsFor: 'testing-properties' stamp: 'lr 3/9/2006 11:31'!
testPropertiesAtIfAbsentPut
	self assert: (self instance propertyAt: #foo put: 'bar') = 'bar'.
	self assert: (self instance propertyAt: #foo ifAbsentPut: [ 'baz' ]) = 'bar'.
	self assert: (self instance propertyAt: #foo) = 'bar'.

	self assert: (self instance propertyAt: #bar ifAbsentPut: [ 'baz' ]) = 'baz'.
	self assert: (self instance propertyAt: #bar) = 'baz'! !

!PRObjectTest methodsFor: 'testing-properties' stamp: 'lr 3/9/2006 11:31'!
testPropertiesAtPut
	self instance propertyAt: #foo put: 'bar'.
	self assert: (self instance propertyAt: #foo) = 'bar'.

	self instance propertyAt: #foo put: 'baz'.
	self assert: (self instance propertyAt: #foo) = 'baz'! !

!PRObjectTest methodsFor: 'testing-properties' stamp: 'lr 3/9/2006 11:31'!
testPropertiesHas
	self deny: (self instance hasProperty: #foo).
	self instance propertyAt: #foo put: 'bar'.
	self assert: (self instance hasProperty: #foo).
	self deny: (self instance hasProperty: #bar)! !

!PRObjectTest methodsFor: 'testing' stamp: 'lr 3/9/2006 11:31'!
testSanity
	"If this test case fails, there is something wrong with the setup of the test-case."

	self
		assert: self actualClass isAbstract not
		description: 'Unable to test abstract class.'.
	self
		assert: self instance class = self actualClass
		description: 'Invalid test instance.'! !

PRObjectTest subclass: #PRPersistencyTest
	instanceVariableNames: 'kernel'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Pier-Tests-Persistence'!

!PRPersistencyTest commentStamp: 'kph 10/4/2006 19:56' prior: 0!
For persistency tests we do not bypass PRKernel instances, 
instead we use kernels prefixed with '####'.!

PRPersistencyTest subclass: #PRImagePersistencyTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Pier-Tests-Persistence'!

!PRImagePersistencyTest class methodsFor: 'testing' stamp: 'lr 3/30/2007 22:22'!
isAbstract
	^ false! !

!PRImagePersistencyTest methodsFor: 'private' stamp: 'lr 3/30/2007 22:22'!
actualClass
	^ PRImagePersistency! !

PRPersistencyTest subclass: #PRNullPersistencyTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Pier-Tests-Persistence'!

!PRNullPersistencyTest class methodsFor: 'testing' stamp: 'lr 3/30/2007 22:22'!
isAbstract
	^ false! !

!PRNullPersistencyTest methodsFor: 'private' stamp: 'lr 3/30/2007 22:22'!
actualClass
	^ PRNullPersistency! !

!PRPersistencyTest class methodsFor: 'testing' stamp: 'lr 3/30/2007 22:22'!
isAbstract
	^ true! !

!PRPersistencyTest class methodsFor: 'nil' stamp: 'kph 10/4/2006 11:28'!
shouldInheritSelectors

^true! !

!PRPersistencyTest methodsFor: 'private' stamp: 'lr 3/30/2007 22:22'!
actualClass
	^ PRPersistency! !

!PRPersistencyTest methodsFor: 'accessing' stamp: 'lr 1/17/2007 10:45'!
instance
	^ self persistency! !

!PRPersistencyTest methodsFor: 'accessing' stamp: 'lr 1/17/2007 10:55'!
kernel
	^ kernel ifNil: [ kernel := self kernelInstance ]! !

!PRPersistencyTest methodsFor: 'accessing' stamp: 'lr 1/17/2007 10:51'!
mutex
	^ self persistency mutex! !

!PRPersistencyTest methodsFor: 'accessing' stamp: 'lr 1/17/2007 10:51'!
persistency
	^ self kernel persistency! !

!PRPersistencyTest methodsFor: 'private' stamp: 'lr 1/17/2007 10:55'!
persistencyInstance
	^ self actualClass new! !

!PRPersistencyTest methodsFor: 'running' stamp: 'lr 1/17/2007 10:51'!
tearDown
	self kernel persistency: PRNullPersistency new! !

!PRPersistencyTest methodsFor: 'testing-mutex' stamp: 'lr 3/5/2007 14:04'!
testMutexError
	"An error inside the critical section should properly unlock it for others to enter."

	| marker |
	marker := nil.
	self
		should: [ self mutex critical: [ 1 / 0 ] ]
		raise: ZeroDivide.

	self mutex critical: [ marker := 1 ].
	self assert: marker = 1! !

!PRPersistencyTest methodsFor: 'testing-mutex' stamp: 'lr 9/24/2007 19:15'!
testMutexForked
	"Two different processed are not allowed to be inside the critical section at once."

	| in1 sem1 in2 sem2  |
	in1 := false.
	in2 := false.

	sem1 := Semaphore new.
	sem2 := Semaphore new.

	[ self mutex critical: [ in1 := true. sem1 signal. sem2 wait ] ] fork.
	[ self mutex critical: [ in2 := true. sem1 signal. sem2 wait ] ] fork.

	sem1 wait.
	self deny: in1 = in2.
	sem2 signal.

	sem1 wait.
	self assert: in1.
	self assert: in2.
	sem2 signal! !

!PRPersistencyTest methodsFor: 'testing-mutex' stamp: 'lr 1/17/2007 10:52'!
testMutexSimple
	| marker |
	marker := nil.
	self mutex critical: [ marker := 1 ].
	self assert: marker = 1! !

!PRPersistencyTest methodsFor: 'testing' stamp: 'lr 1/17/2007 11:22'!
testSetup
	self assert: self persistency kernel = self kernel.
	self assert: self kernel persistency = self persistency! !

TestCase subclass: #PRUtilitiesTests
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Pier-Tests-Utilities'!

!PRUtilitiesTests methodsFor: 'testing-escaper' stamp: 'lr 10/30/2006 19:49'!
testEnsureEscape
	| visitor tag |
	visitor := PRVisitor new.
	tag := nil.

	self assert: (visitor withEscaper: [
		[ true ]
			ensure: [ tag := 1 ] ]).
	self assert: tag = 1.

	self assert: (visitor withEscaper: [
		[ visitor escape: true ]
			ensure: [ tag := 2 ] ]).
	self assert: tag = 2! !

!PRUtilitiesTests methodsFor: 'testing-escaper' stamp: 'lr 2/12/2007 19:07'!
testEscaper
	| visitor |
	visitor := PRVisitor new.

	self assert: (visitor withEscaper: [ true ]).
	self deny: (visitor withEscaper: [ false ]).

	self assert: (visitor withEscaper: [ visitor escape: true. false ]).
	self deny: (visitor withEscaper: [ visitor escape: false. true ])! !

!PRUtilitiesTests methodsFor: 'testing-escaper' stamp: 'lr 10/30/2006 19:49'!
testHasEscaper
	| visitor |
	visitor := PRVisitor new.
	self deny: visitor hasEscaper.
	self assert: (visitor withEscaper: [ visitor hasEscaper ])! !

!PRUtilitiesTests methodsFor: 'testing-expander' stamp: 'lr 3/9/2006 11:31'!
testMacroInitialized
	| expander |
	expander := PRMacroExpander new.

	self assert: expander character = $%.
	self assert: expander default notNil.
	self assert: expander table isEmpty! !

!PRUtilitiesTests methodsFor: 'testing-expander' stamp: 'lr 3/9/2006 11:31'!
testMacroValue
	| expander |
	expander := PRMacroExpander new.
	expander table
		at: $1 put: [ '!!1' ];
		at: $2 put: [ '!!2' ].

	self assert: (expander value: '') = ''.
	self assert: (expander value: 'xyz') = 'xyz'.

	self assert: (expander value: '%1') = '!!1'.
	self assert: (expander value: '%2') = '!!2'.

	self assert: (expander value: '%1xy') = '!!1xy'.
	self assert: (expander value: 'x%1y') = 'x!!1y'.
	self assert: (expander value: 'xy%1') = 'xy!!1'.

	self assert: (expander value: '%2xy') = '!!2xy'.
	self assert: (expander value: 'x%2y') = 'x!!2y'.
	self assert: (expander value: 'xy%2') = 'xy!!2'.

	self assert: (expander value: '%1%2') = '!!1!!2'.
	self assert: (expander value: 'x%1%2') = 'x!!1!!2'.
	self assert: (expander value: 'x%1y%2') = 'x!!1y!!2'.
	self assert: (expander value: 'x%1y%2z') = 'x!!1y!!2z'.

	self assert: (expander value: '%%') = '%'.
	self assert: (expander value: '%3') = '%3'! !

!PRUtilitiesTests methodsFor: 'testing-expander' stamp: 'lr 3/9/2006 11:31'!
testMacroValueValue
	| expander |
	expander := PRMacroExpander new.
	expander table
		at: $1 put: [ :char | '!!' , char asString ];
		at: $2 put: [ :char | '!!' , char asString ].

	self assert: (expander value: '') = ''.
	self assert: (expander value: 'xyz') = 'xyz'.

	self assert: (expander value: '%1') = '!!1'.
	self assert: (expander value: '%2') = '!!2'.

	self assert: (expander value: '%1xy') = '!!1xy'.
	self assert: (expander value: 'x%1y') = 'x!!1y'.
	self assert: (expander value: 'xy%1') = 'xy!!1'.

	self assert: (expander value: '%2xy') = '!!2xy'.
	self assert: (expander value: 'x%2y') = 'x!!2y'.
	self assert: (expander value: 'xy%2') = 'xy!!2'.

	self assert: (expander value: '%1%2') = '!!1!!2'.
	self assert: (expander value: 'x%1%2') = 'x!!1!!2'.
	self assert: (expander value: 'x%1y%2') = 'x!!1y!!2'.
	self assert: (expander value: 'x%1y%2z') = 'x!!1y!!2z'.

	self assert: (expander value: '%%') = '%'.
	self assert: (expander value: '%3') = '%3'! !

!PRUtilitiesTests methodsFor: 'testing-expander' stamp: 'lr 3/9/2006 11:31'!
testMacroValueValueValue
	| expander |
	expander := PRMacroExpander new.
	expander table
		at: $1 put: [ :char :arg | arg , char asString ];
		at: $2 put: [ :char :arg | arg , char asString ].

	self assert: (expander value: '') = ''.
	self assert: (expander value: 'xyz') = 'xyz'.

	self assert: (expander value: '%1' value: '!!') = '!!1'.
	self assert: (expander value: '%2' value: '!!') = '!!2'.

	self assert: (expander value: '%1xy' value: '!!') = '!!1xy'.
	self assert: (expander value: 'x%1y' value: '!!') = 'x!!1y'.
	self assert: (expander value: 'xy%1' value: '!!') = 'xy!!1'.

	self assert: (expander value: '%2xy' value: '!!') = '!!2xy'.
	self assert: (expander value: 'x%2y' value: '!!') = 'x!!2y'.
	self assert: (expander value: 'xy%2' value: '!!') = 'xy!!2'.

	self assert: (expander value: '%1%2' value: '!!') = '!!1!!2'.
	self assert: (expander value: 'x%1%2' value: '!!') = 'x!!1!!2'.
	self assert: (expander value: 'x%1y%2' value: '!!') = 'x!!1y!!2'.
	self assert: (expander value: 'x%1y%2z' value: '!!') = 'x!!1y!!2z'! !

TestCase subclass: #PRVisitorTests
	instanceVariableNames: 'root folder child1 child2'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Pier-Tests-Utilities'!

!PRVisitorTests methodsFor: 'running' stamp: 'lr 2/12/2007 19:07'!
setUp
	root := PRPage named: 'root'.
	folder := PRPage named: 'folder'.
	child1 := PRPage named: 'child1'.
	child2 := PRPage named: 'child2'.

	root addChild: folder.
	folder addChild: child1.
	folder addChild: child2! !

!PRVisitorTests methodsFor: 'testing-incoming' stamp: 'lr 1/19/2007 13:59'!
testIncomingReferencesMultiple
	| matched |
	root contents: '*folder*'.
	folder contents: '*child1* *child2*'.
	child1 contents: '*/*'.
	child2 contents: ''.

	matched := root incomingReferences
		toAll: (Array with: root with: folder);
		collect: [ :each | each owner ].
	self assert: (matched collect: [ :each | each name ]) = #( 'root' 'child1' ).
	matched := folder incomingReferences
		toAll: (Array with: root with: folder);
		collect: [ :each | each owner ].
	self assert: (matched collect: [ :each | each name ]) = #( 'child1' ).
	matched := folder incomingReferences
		toAll: (Array with: child1 with: child2);
		collect: [ :each | each owner ].
	self assert: (matched collect: [ :each | each name ]) = #( 'folder' 'folder' )! !

!PRVisitorTests methodsFor: 'testing-incoming' stamp: 'lr 2/12/2007 19:07'!
testIncomingReferencesSingle
	| matched |
	root contents: '*folder*'.
	folder contents: '*child1* *child2*'.
	child1 contents: '*/*'.
	child2 contents: ''.

	matched := root incomingReferences
		to: root;
		collect: [ :each | each owner ].
	self assert: (matched collect: [ :each | each name ]) = #( 'child1' ).
	matched := root incomingReferences
		to: folder;
		collect: [ :each | each owner ].
	self assert: (matched collect: [ :each | each name ]) = #( 'root' ).
	matched := root incomingReferences
		to: child1;
		collect: [ :each | each owner ].
	self assert: (matched collect: [ :each | each name ]) = #( 'folder' ).
	matched := root incomingReferences
		to: child2;
		collect: [ :each | each owner ].
	self assert: (matched collect: [ :each | each name ]) = #( 'folder' )! !

!PRVisitorTests methodsFor: 'testing-outgoing' stamp: 'lr 2/12/2007 19:07'!
testOutgoingReferencesContinue
	| matched |
	root contents: '+folder+'.
	folder contents: '+child1+ +child2+'.
	child1 contents: '+/+'.
	child2 contents: ''.

	matched := root outgoingReferences
		continue: [ :each | false ];
		collect: [ :each | each target ].
	self assert: (matched collect: [ :each | each name ]) = #( 'folder' ).
	matched := root outgoingReferences
		continue: [ :each | each owner = root ];
		collect: [ :each | each target ].
	self assert: (matched collect: [ :each | each name ]) = #( 'folder' 'child1' 'child2' ).
	matched := root outgoingReferences
		continue: [ :each | each target ~= child1 ];
		collect: [ :each | each target ].
	self assert: (matched collect: [ :each | each name ]) = #( 'folder' 'child1' 'child2' )! !

!PRVisitorTests methodsFor: 'testing-outgoing' stamp: 'lr 2/12/2007 19:07'!
testOutgoingReferencesEmbedded
	| matched |
	root contents: '+folder+'.
	folder contents: '+child1+ +child2+'.
	child1 contents: '+/+'.
	child2 contents: ''.

	matched := root outgoingReferences collect: [ :each | each target ].
	self assert: (matched collect: [ :each | each name ]) = #( 'folder' 'child1' 'root' 'child2' ).
	matched := folder outgoingReferences collect: [ :each | each target ].
	self assert: (matched collect: [ :each | each name ]) = #( 'child1' 'root' 'folder' 'child2' ).
	matched := child1 outgoingReferences collect: [ :each | each target ].
	self assert: (matched collect: [ :each | each name ]) = #( 'root' 'folder' 'child1' 'child2' ).
	matched := child2 outgoingReferences collect: [ :each | each target ].
	self assert: (matched collect: [ :each | each name ]) = #( )! !

!PRVisitorTests methodsFor: 'testing-outgoing' stamp: 'lr 2/12/2007 19:07'!
testOutgoingReferencesStandard
	| matched |
	root contents: '*folder*'.
	folder contents: '*child1* *child2*'.
	child1 contents: '*/*'.
	child2 contents: ''.

	matched := root outgoingReferences collect: [ :each | each target ].
	self assert: (matched collect: [ :each | each name ]) = #( 'folder' ).
	matched := folder outgoingReferences collect: [ :each | each target ].
	self assert: (matched collect: [ :each | each name ]) = #( 'child1' 'child2' ).
	matched := child1 outgoingReferences collect: [ :each | each target ].
	self assert: (matched collect: [ :each | each name ]) = #( 'root' ).
	matched := child2 outgoingReferences collect: [ :each | each target ].
	self assert: (matched collect: [ :each | each name ]) = #( )! !

!PRVisitorTests methodsFor: 'testing-search' stamp: 'lr 2/12/2007 19:07'!
testSearchCaseSensitive
	| match |
	root contents: 'struct 1 foo'.
	folder contents: 'struct 2 bar'.
	child1 contents: 'struct 3 zork'.
	child2 contents: 'struct 4 plonk'.

	match := root fullTextSearch subString: 'Bar'; caseSensitive: true.
	self assert: (match collect: [ :each | each name ]) = #( ).
	match := root fullTextSearch subString: 'bar'; caseSensitive: true.
	self assert: (match collect: [ :each | each name ]) = #( 'folder' ).

	match := root fullTextSearch subString: 'Bar'; caseSensitive: false.
	self assert: (match collect: [ :each | each name ]) = #( 'folder' ).
	match := root fullTextSearch subString: 'bar'; caseSensitive: false.
	self assert: (match collect: [ :each | each name ]) = #( 'folder' ).

	match := root fullTextSearch subString: 'Bar'.
	self assert: (match collect: [ :each | each name ]) = #( 'folder' ).
	match := root fullTextSearch subString: 'bar'.
	self assert: (match collect: [ :each | each name ]) = #( 'folder' )! !

!PRVisitorTests methodsFor: 'testing-search' stamp: 'lr 2/12/2007 19:07'!
testSearchContents
	| match |
	root contents: 'struct 1 foo'.
	folder contents: 'struct 2 bar'.
	child1 contents: 'struct 3 zork'.
	child2 contents: 'struct 4 plonk'.

	match := root fullTextSearch subString: 'foo'.
	self assert: (match collect: [ :each | each name ]) = #( 'root' ).
	match := root fullTextSearch subString: 'bar'.
	self assert: (match collect: [ :each | each name ]) = #( 'folder' ).
	match := root fullTextSearch subString: 'zork'.
	self assert: (match collect: [ :each | each name ]) = #( 'child1' ).
	match := root fullTextSearch subString: 'plonk'.
	self assert: (match collect: [ :each | each name ]) = #( 'child2' )! !

!PRVisitorTests methodsFor: 'testing-search' stamp: 'lr 2/12/2007 19:07'!
testSearchMultiple
	| match |
	root contents: 'struct 1 foo'.
	folder contents: 'struct 2 bar'.
	child1 contents: 'struct 3 zork'.
	child2 contents: 'struct 4 plonk'.

	match := root fullTextSearch subString: '1'.
	self assert: (match collect: [ :each | each name ]) = #( 'root' 'child1' ).
	match := root fullTextSearch subString: '2'.
	self assert: (match collect: [ :each | each name ]) = #( 'folder' 'child2' )! !

!PRVisitorTests methodsFor: 'testing-search' stamp: 'lr 2/12/2007 19:07'!
testSearchNonRoot
	| match |
	root contents: 'struct 1 foo'.
	folder contents: 'struct 2 bar'.
	child1 contents: 'struct 3 zork'.
	child2 contents: 'struct 4 plonk'.

	match := root fullTextSearch subString: 'plonk'.
	self assert: (match collect: [ :each | each name ]) = #( 'child2'  ).
	match := folder fullTextSearch subString: 'plonk'.
	self assert: (match collect: [ :each | each name ]) = #( 'child2'  ).
	match := child1 fullTextSearch subString: 'plonk'.
	self assert: (match collect: [ :each | each name ]) = #(  ).
	match := child2 fullTextSearch subString: 'plonk'.
	self assert: (match collect: [ :each | each name ]) = #( 'child2' )! !

!PRVisitorTests methodsFor: 'testing-search' stamp: 'lr 2/12/2007 19:07'!
testSearchTitle
	| match |
	root contents: 'struct 1 foo'.
	folder contents: 'struct 2 bar'.
	child1 contents: 'struct 3 zork'.
	child2 contents: 'struct 4 plonk'.

	match := root fullTextSearch subString: 'root'.
	self assert: (match collect: [ :each | each name ]) = #( 'root' ).
	match := root fullTextSearch subString: 'folder'.
	self assert: (match collect: [ :each | each name ]) = #( 'folder' ).
	match := root fullTextSearch subString: 'child1'.
	self assert: (match collect: [ :each | each name ]) = #( 'child1' ).
	match := root fullTextSearch subString: 'child2'.
	self assert: (match collect: [ :each | each name ]) = #( 'child2' )! !

PRDecoration subclass: #PRMockDecoration
	instanceVariableNames: 'priority'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Pier-Tests-Mocks'!

!PRMockDecoration class methodsFor: 'testing' stamp: 'lr 3/9/2006 11:30'!
isAbstract
	^ false! !

!PRMockDecoration methodsFor: 'comparing' stamp: 'lr 3/9/2006 11:29'!
= aDecoration
	^ super = aDecoration
		and: [ self priority = aDecoration priority ]! !

!PRMockDecoration methodsFor: 'comparing' stamp: 'lr 3/9/2006 11:29'!
hash
	^ super hash bitXor: self priority hash! !

!PRMockDecoration methodsFor: 'accessing' stamp: 'lr 3/9/2006 11:29'!
priority
	^ priority! !

!PRMockDecoration methodsFor: 'accessing' stamp: 'lr 3/9/2006 11:29'!
priority: anInteger
	priority := anInteger! !
